compute

package
v0.0.0-...-52a6fbd Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_temporal_api_next_compute_v1_config_proto protoreflect.FileDescriptor
var File_temporal_api_next_compute_v1_provider_proto protoreflect.FileDescriptor
var File_temporal_api_next_compute_v1_scaler_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type ComputeConfig

type ComputeConfig struct {

	// Each scaling group describes a compute config for a specific subset of the worker
	// deployment version: covering a specific set of task types and/or regions.
	// Having different configurations for different task types, allows independent
	// tuning of activity and workflow task processing (for example).
	//
	// The key of the map is the ID of the scaling group used to reference it in subsequent
	// update calls.
	ScalingGroups map[string]*ComputeConfigScalingGroup `` /* 174-byte string literal not displayed */
	// contains filtered or unexported fields
}

ComputeConfig stores configuration that helps a worker control plane controller understand *when* and *how* to respond to worker lifecycle events.

func (*ComputeConfig) Descriptor deprecated

func (*ComputeConfig) Descriptor() ([]byte, []int)

Deprecated: Use ComputeConfig.ProtoReflect.Descriptor instead.

func (*ComputeConfig) GetScalingGroups

func (x *ComputeConfig) GetScalingGroups() map[string]*ComputeConfigScalingGroup

func (*ComputeConfig) ProtoMessage

func (*ComputeConfig) ProtoMessage()

func (*ComputeConfig) ProtoReflect

func (x *ComputeConfig) ProtoReflect() protoreflect.Message

func (*ComputeConfig) Reset

func (x *ComputeConfig) Reset()

func (*ComputeConfig) String

func (x *ComputeConfig) String() string

type ComputeConfigScalingGroup

type ComputeConfigScalingGroup struct {

	// Optional. The set of task queue types this scaling group serves.
	// If not provided, this scaling group serves all not otherwise defined
	// task types.
	TaskQueueTypes []v1.TaskQueueType `` /* 154-byte string literal not displayed */
	// Stores instructions for a worker control plane controller how to respond
	// to worker lifeycle events.
	Provider *ComputeProvider `protobuf:"bytes,3,opt,name=provider,proto3" json:"provider,omitempty"`
	// Informs a worker lifecycle controller *when* and *how often* to perform
	// certain worker lifecycle actions like starting a serverless worker.
	Scaler *ComputeScaler `protobuf:"bytes,4,opt,name=scaler,proto3" json:"scaler,omitempty"`
	// contains filtered or unexported fields
}

func (*ComputeConfigScalingGroup) Descriptor deprecated

func (*ComputeConfigScalingGroup) Descriptor() ([]byte, []int)

Deprecated: Use ComputeConfigScalingGroup.ProtoReflect.Descriptor instead.

func (*ComputeConfigScalingGroup) GetProvider

func (x *ComputeConfigScalingGroup) GetProvider() *ComputeProvider

func (*ComputeConfigScalingGroup) GetScaler

func (x *ComputeConfigScalingGroup) GetScaler() *ComputeScaler

func (*ComputeConfigScalingGroup) GetTaskQueueTypes

func (x *ComputeConfigScalingGroup) GetTaskQueueTypes() []v1.TaskQueueType

func (*ComputeConfigScalingGroup) ProtoMessage

func (*ComputeConfigScalingGroup) ProtoMessage()

func (*ComputeConfigScalingGroup) ProtoReflect

func (*ComputeConfigScalingGroup) Reset

func (x *ComputeConfigScalingGroup) Reset()

func (*ComputeConfigScalingGroup) String

func (x *ComputeConfigScalingGroup) String() string

type ComputeConfigScalingGroupSummary

type ComputeConfigScalingGroupSummary struct {
	TaskQueueTypes []v1.TaskQueueType `` /* 154-byte string literal not displayed */
	ProviderType   string             `protobuf:"bytes,2,opt,name=provider_type,json=providerType,proto3" json:"provider_type,omitempty"`
	// contains filtered or unexported fields
}

func (*ComputeConfigScalingGroupSummary) Descriptor deprecated

func (*ComputeConfigScalingGroupSummary) Descriptor() ([]byte, []int)

Deprecated: Use ComputeConfigScalingGroupSummary.ProtoReflect.Descriptor instead.

func (*ComputeConfigScalingGroupSummary) GetProviderType

func (x *ComputeConfigScalingGroupSummary) GetProviderType() string

func (*ComputeConfigScalingGroupSummary) GetTaskQueueTypes

func (x *ComputeConfigScalingGroupSummary) GetTaskQueueTypes() []v1.TaskQueueType

func (*ComputeConfigScalingGroupSummary) ProtoMessage

func (*ComputeConfigScalingGroupSummary) ProtoMessage()

func (*ComputeConfigScalingGroupSummary) ProtoReflect

func (*ComputeConfigScalingGroupSummary) Reset

func (*ComputeConfigScalingGroupSummary) String

type ComputeConfigScalingGroupUpdate

type ComputeConfigScalingGroupUpdate struct {
	ScalingGroup *ComputeConfigScalingGroup `protobuf:"bytes,1,opt,name=scaling_group,json=scalingGroup,proto3" json:"scaling_group,omitempty"`
	// Controls which fields from `scaling_group` will be applied. Semantics:
	//   - Mask is ignored for new scaling groups (only applicable when scaling group already exists).
	//   - Empty mask for an existing scaling group is no-op: no change.
	//   - Non-empty mask for an existing scaling group will update/unset only to the fields
	//     mentioned in the mask.
	//   - Accepted paths: "task_queue_types", "provider", "provider.type", "provider.details",
	//     "provider.nexus_endpoint", "scaler", "scaler.type", "scaler.details"
	UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	// contains filtered or unexported fields
}

func (*ComputeConfigScalingGroupUpdate) Descriptor deprecated

func (*ComputeConfigScalingGroupUpdate) Descriptor() ([]byte, []int)

Deprecated: Use ComputeConfigScalingGroupUpdate.ProtoReflect.Descriptor instead.

func (*ComputeConfigScalingGroupUpdate) GetScalingGroup

func (*ComputeConfigScalingGroupUpdate) GetUpdateMask

func (*ComputeConfigScalingGroupUpdate) ProtoMessage

func (*ComputeConfigScalingGroupUpdate) ProtoMessage()

func (*ComputeConfigScalingGroupUpdate) ProtoReflect

func (*ComputeConfigScalingGroupUpdate) Reset

func (*ComputeConfigScalingGroupUpdate) String

type ComputeConfigSummary

type ComputeConfigSummary struct {
	ScalingGroups map[string]*ComputeConfigScalingGroupSummary `` /* 174-byte string literal not displayed */
	// contains filtered or unexported fields
}

A subset of information in ComputeConfig optimized for list views.

func (*ComputeConfigSummary) Descriptor deprecated

func (*ComputeConfigSummary) Descriptor() ([]byte, []int)

Deprecated: Use ComputeConfigSummary.ProtoReflect.Descriptor instead.

func (*ComputeConfigSummary) GetScalingGroups

func (*ComputeConfigSummary) ProtoMessage

func (*ComputeConfigSummary) ProtoMessage()

func (*ComputeConfigSummary) ProtoReflect

func (x *ComputeConfigSummary) ProtoReflect() protoreflect.Message

func (*ComputeConfigSummary) Reset

func (x *ComputeConfigSummary) Reset()

func (*ComputeConfigSummary) String

func (x *ComputeConfigSummary) String() string

type ComputeProvider

type ComputeProvider struct {

	// Type of the compute provider. This string is implementation-specific and
	// can be used by implementations to understand how to interpret the
	// contents of the provider_details field.
	Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	// Contains provider-specific instructions and configuration.
	// For server-implemented providers, use the SDK's default content
	// converter to ensure the server can understand it.
	// For remote-implemented providers, you might use your own content
	// converters according to what the remote endpoints understand.
	Details *v1.Payload `protobuf:"bytes,2,opt,name=details,proto3" json:"details,omitempty"`
	// Optional. If the compute provider is a Nexus service, this should point
	// there.
	NexusEndpoint string `protobuf:"bytes,10,opt,name=nexus_endpoint,json=nexusEndpoint,proto3" json:"nexus_endpoint,omitempty"`
	// contains filtered or unexported fields
}

ComputeProvider stores information used by a worker control plane controller to respond to worker lifecycle events. For example, when a Task is received on a TaskQueue that has no active pollers, a serverless worker lifecycle controller might need to invoke an AWS Lambda Function that itself ends up calling the SDK's worker.New() function.

func (*ComputeProvider) Descriptor deprecated

func (*ComputeProvider) Descriptor() ([]byte, []int)

Deprecated: Use ComputeProvider.ProtoReflect.Descriptor instead.

func (*ComputeProvider) GetDetails

func (x *ComputeProvider) GetDetails() *v1.Payload

func (*ComputeProvider) GetNexusEndpoint

func (x *ComputeProvider) GetNexusEndpoint() string

func (*ComputeProvider) GetType

func (x *ComputeProvider) GetType() string

func (*ComputeProvider) ProtoMessage

func (*ComputeProvider) ProtoMessage()

func (*ComputeProvider) ProtoReflect

func (x *ComputeProvider) ProtoReflect() protoreflect.Message

func (*ComputeProvider) Reset

func (x *ComputeProvider) Reset()

func (*ComputeProvider) String

func (x *ComputeProvider) String() string

type ComputeScaler

type ComputeScaler struct {

	// Type of the compute scaler. this string is implementation-specific and
	// can be used by implementations to understand how to interpret the
	// contents of the scaler_details field.
	Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
	// Contains scaler-specific instructions and configuration.
	// For server-implemented scalers, use the SDK's default data
	// converter to ensure the server can understand it.
	// For remote-implemented scalers, you might use your own data
	// converters according to what the remote endpoints understand.
	Details *v1.Payload `protobuf:"bytes,2,opt,name=details,proto3" json:"details,omitempty"`
	// contains filtered or unexported fields
}

ComputeScaler instructs the Temporal Service when to scale up or down the number of Workers that comprise a WorkerDeployment.

func (*ComputeScaler) Descriptor deprecated

func (*ComputeScaler) Descriptor() ([]byte, []int)

Deprecated: Use ComputeScaler.ProtoReflect.Descriptor instead.

func (*ComputeScaler) GetDetails

func (x *ComputeScaler) GetDetails() *v1.Payload

func (*ComputeScaler) GetType

func (x *ComputeScaler) GetType() string

func (*ComputeScaler) ProtoMessage

func (*ComputeScaler) ProtoMessage()

func (*ComputeScaler) ProtoReflect

func (x *ComputeScaler) ProtoReflect() protoreflect.Message

func (*ComputeScaler) Reset

func (x *ComputeScaler) Reset()

func (*ComputeScaler) String

func (x *ComputeScaler) String() string

Jump to