Documentation
¶
Index ¶
- Variables
- type ActivityType
- type Callback
- func (*Callback) Descriptor() ([]byte, []int)deprecated
- func (x *Callback) GetInternal() *Callback_Internal
- func (x *Callback) GetLinks() []*Link
- func (x *Callback) GetNexus() *Callback_Nexus
- func (x *Callback) GetVariant() isCallback_Variant
- func (*Callback) ProtoMessage()
- func (x *Callback) ProtoReflect() protoreflect.Message
- func (x *Callback) Reset()
- func (x *Callback) String() string
- type Callback_Internal
- type Callback_Internal_
- type Callback_Nexus
- func (*Callback_Nexus) Descriptor() ([]byte, []int)deprecated
- func (x *Callback_Nexus) GetHeader() map[string]string
- func (x *Callback_Nexus) GetUrl() string
- func (*Callback_Nexus) ProtoMessage()
- func (x *Callback_Nexus) ProtoReflect() protoreflect.Message
- func (x *Callback_Nexus) Reset()
- func (x *Callback_Nexus) String() string
- type Callback_Nexus_
- type DataBlob
- type Header
- type Link
- func (*Link) Descriptor() ([]byte, []int)deprecated
- func (x *Link) GetActivity() *Link_Activity
- func (x *Link) GetBatchJob() *Link_BatchJob
- func (x *Link) GetNexusOperation() *Link_NexusOperation
- func (x *Link) GetVariant() isLink_Variant
- func (x *Link) GetWorkflowEvent() *Link_WorkflowEvent
- func (*Link) ProtoMessage()
- func (x *Link) ProtoReflect() protoreflect.Message
- func (x *Link) Reset()
- func (x *Link) String() string
- type Link_Activity
- func (*Link_Activity) Descriptor() ([]byte, []int)deprecated
- func (x *Link_Activity) GetActivityId() string
- func (x *Link_Activity) GetNamespace() string
- func (x *Link_Activity) GetRunId() string
- func (*Link_Activity) ProtoMessage()
- func (x *Link_Activity) ProtoReflect() protoreflect.Message
- func (x *Link_Activity) Reset()
- func (x *Link_Activity) String() string
- type Link_Activity_
- type Link_BatchJob
- type Link_BatchJob_
- type Link_NexusOperation
- func (*Link_NexusOperation) Descriptor() ([]byte, []int)deprecated
- func (x *Link_NexusOperation) GetNamespace() string
- func (x *Link_NexusOperation) GetOperationId() string
- func (x *Link_NexusOperation) GetRunId() string
- func (*Link_NexusOperation) ProtoMessage()
- func (x *Link_NexusOperation) ProtoReflect() protoreflect.Message
- func (x *Link_NexusOperation) Reset()
- func (x *Link_NexusOperation) String() string
- type Link_NexusOperation_
- type Link_WorkflowEvent
- func (*Link_WorkflowEvent) Descriptor() ([]byte, []int)deprecated
- func (x *Link_WorkflowEvent) GetEventRef() *Link_WorkflowEvent_EventReference
- func (x *Link_WorkflowEvent) GetNamespace() string
- func (x *Link_WorkflowEvent) GetReference() isLink_WorkflowEvent_Reference
- func (x *Link_WorkflowEvent) GetRequestIdRef() *Link_WorkflowEvent_RequestIdReference
- func (x *Link_WorkflowEvent) GetRunId() string
- func (x *Link_WorkflowEvent) GetWorkflowId() string
- func (*Link_WorkflowEvent) ProtoMessage()
- func (x *Link_WorkflowEvent) ProtoReflect() protoreflect.Message
- func (x *Link_WorkflowEvent) Reset()
- func (x *Link_WorkflowEvent) String() string
- type Link_WorkflowEvent_
- type Link_WorkflowEvent_EventRef
- type Link_WorkflowEvent_EventReference
- func (*Link_WorkflowEvent_EventReference) Descriptor() ([]byte, []int)deprecated
- func (x *Link_WorkflowEvent_EventReference) GetEventId() int64
- func (x *Link_WorkflowEvent_EventReference) GetEventType() v1.EventType
- func (*Link_WorkflowEvent_EventReference) ProtoMessage()
- func (x *Link_WorkflowEvent_EventReference) ProtoReflect() protoreflect.Message
- func (x *Link_WorkflowEvent_EventReference) Reset()
- func (x *Link_WorkflowEvent_EventReference) String() string
- type Link_WorkflowEvent_RequestIdRef
- type Link_WorkflowEvent_RequestIdReference
- func (*Link_WorkflowEvent_RequestIdReference) Descriptor() ([]byte, []int)deprecated
- func (x *Link_WorkflowEvent_RequestIdReference) GetEventType() v1.EventType
- func (x *Link_WorkflowEvent_RequestIdReference) GetRequestId() string
- func (*Link_WorkflowEvent_RequestIdReference) ProtoMessage()
- func (x *Link_WorkflowEvent_RequestIdReference) ProtoReflect() protoreflect.Message
- func (x *Link_WorkflowEvent_RequestIdReference) Reset()
- func (x *Link_WorkflowEvent_RequestIdReference) String() string
- type Memo
- type MeteringMetadata
- func (*MeteringMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *MeteringMetadata) GetNonfirstLocalActivityExecutionAttempts() uint32
- func (*MeteringMetadata) ProtoMessage()
- func (x *MeteringMetadata) ProtoReflect() protoreflect.Message
- func (x *MeteringMetadata) Reset()
- func (x *MeteringMetadata) String() string
- type OnConflictOptions
- func (*OnConflictOptions) Descriptor() ([]byte, []int)deprecated
- func (x *OnConflictOptions) GetAttachCompletionCallbacks() bool
- func (x *OnConflictOptions) GetAttachLinks() bool
- func (x *OnConflictOptions) GetAttachRequestId() bool
- func (*OnConflictOptions) ProtoMessage()
- func (x *OnConflictOptions) ProtoReflect() protoreflect.Message
- func (x *OnConflictOptions) Reset()
- func (x *OnConflictOptions) String() string
- type Payload
- func (*Payload) Descriptor() ([]byte, []int)deprecated
- func (x *Payload) GetData() []byte
- func (x *Payload) GetExternalPayloads() []*Payload_ExternalPayloadDetails
- func (x *Payload) GetMetadata() map[string][]byte
- func (*Payload) ProtoMessage()
- func (x *Payload) ProtoReflect() protoreflect.Message
- func (x *Payload) Reset()
- func (x *Payload) String() string
- type Payload_ExternalPayloadDetails
- func (*Payload_ExternalPayloadDetails) Descriptor() ([]byte, []int)deprecated
- func (x *Payload_ExternalPayloadDetails) GetSizeBytes() int64
- func (*Payload_ExternalPayloadDetails) ProtoMessage()
- func (x *Payload_ExternalPayloadDetails) ProtoReflect() protoreflect.Message
- func (x *Payload_ExternalPayloadDetails) Reset()
- func (x *Payload_ExternalPayloadDetails) String() string
- type Payloads
- type Principal
- type Priority
- func (*Priority) Descriptor() ([]byte, []int)deprecated
- func (x *Priority) GetFairnessKey() string
- func (x *Priority) GetFairnessWeight() float32
- func (x *Priority) GetPriorityKey() int32
- func (*Priority) ProtoMessage()
- func (x *Priority) ProtoReflect() protoreflect.Message
- func (x *Priority) Reset()
- func (x *Priority) String() string
- type ResetOptions
- func (*ResetOptions) Descriptor() ([]byte, []int)deprecated
- func (x *ResetOptions) GetBuildId() string
- func (x *ResetOptions) GetCurrentRunOnly() bool
- func (x *ResetOptions) GetFirstWorkflowTask() *emptypb.Empty
- func (x *ResetOptions) GetLastWorkflowTask() *emptypb.Empty
- func (x *ResetOptions) GetResetReapplyExcludeTypes() []v1.ResetReapplyExcludeType
- func (x *ResetOptions) GetResetReapplyType() v1.ResetReapplyTypedeprecated
- func (x *ResetOptions) GetTarget() isResetOptions_Target
- func (x *ResetOptions) GetWorkflowTaskId() int64
- func (*ResetOptions) ProtoMessage()
- func (x *ResetOptions) ProtoReflect() protoreflect.Message
- func (x *ResetOptions) Reset()
- func (x *ResetOptions) String() string
- type ResetOptions_BuildId
- type ResetOptions_FirstWorkflowTask
- type ResetOptions_LastWorkflowTask
- type ResetOptions_WorkflowTaskId
- type RetryPolicy
- func (*RetryPolicy) Descriptor() ([]byte, []int)deprecated
- func (x *RetryPolicy) GetBackoffCoefficient() float64
- func (x *RetryPolicy) GetInitialInterval() *durationpb.Duration
- func (x *RetryPolicy) GetMaximumAttempts() int32
- func (x *RetryPolicy) GetMaximumInterval() *durationpb.Duration
- func (x *RetryPolicy) GetNonRetryableErrorTypes() []string
- func (*RetryPolicy) ProtoMessage()
- func (x *RetryPolicy) ProtoReflect() protoreflect.Message
- func (x *RetryPolicy) Reset()
- func (x *RetryPolicy) String() string
- type SearchAttributes
- func (*SearchAttributes) Descriptor() ([]byte, []int)deprecated
- func (x *SearchAttributes) GetIndexedFields() map[string]*Payload
- func (*SearchAttributes) ProtoMessage()
- func (x *SearchAttributes) ProtoReflect() protoreflect.Message
- func (x *SearchAttributes) Reset()
- func (x *SearchAttributes) String() string
- type WorkerSelector
- func (*WorkerSelector) Descriptor() ([]byte, []int)deprecated
- func (x *WorkerSelector) GetSelector() isWorkerSelector_Selector
- func (x *WorkerSelector) GetWorkerInstanceKey() string
- func (*WorkerSelector) ProtoMessage()
- func (x *WorkerSelector) ProtoReflect() protoreflect.Message
- func (x *WorkerSelector) Reset()
- func (x *WorkerSelector) String() string
- type WorkerSelector_WorkerInstanceKey
- type WorkerVersionCapabilities
- func (*WorkerVersionCapabilities) Descriptor() ([]byte, []int)deprecated
- func (x *WorkerVersionCapabilities) GetBuildId() string
- func (x *WorkerVersionCapabilities) GetDeploymentSeriesName() string
- func (x *WorkerVersionCapabilities) GetUseVersioning() bool
- func (*WorkerVersionCapabilities) ProtoMessage()
- func (x *WorkerVersionCapabilities) ProtoReflect() protoreflect.Message
- func (x *WorkerVersionCapabilities) Reset()
- func (x *WorkerVersionCapabilities) String() string
- type WorkerVersionStamp
- func (*WorkerVersionStamp) Descriptor() ([]byte, []int)deprecated
- func (x *WorkerVersionStamp) GetBuildId() string
- func (x *WorkerVersionStamp) GetUseVersioning() bool
- func (*WorkerVersionStamp) ProtoMessage()
- func (x *WorkerVersionStamp) ProtoReflect() protoreflect.Message
- func (x *WorkerVersionStamp) Reset()
- func (x *WorkerVersionStamp) String() string
- type WorkflowExecution
- func (*WorkflowExecution) Descriptor() ([]byte, []int)deprecated
- func (x *WorkflowExecution) GetRunId() string
- func (x *WorkflowExecution) GetWorkflowId() string
- func (*WorkflowExecution) ProtoMessage()
- func (x *WorkflowExecution) ProtoReflect() protoreflect.Message
- func (x *WorkflowExecution) Reset()
- func (x *WorkflowExecution) String() string
- type WorkflowType
Constants ¶
This section is empty.
Variables ¶
var File_temporal_api_next_common_v1_message_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ActivityType ¶
type ActivityType struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Represents the identifier used by a activity author to define the activity. Typically, the name of a function. This is sometimes referred to as the activity's "name"
func (*ActivityType) Descriptor
deprecated
func (*ActivityType) Descriptor() ([]byte, []int)
Deprecated: Use ActivityType.ProtoReflect.Descriptor instead.
func (*ActivityType) GetName ¶
func (x *ActivityType) GetName() string
func (*ActivityType) ProtoMessage ¶
func (*ActivityType) ProtoMessage()
func (*ActivityType) ProtoReflect ¶
func (x *ActivityType) ProtoReflect() protoreflect.Message
func (*ActivityType) Reset ¶
func (x *ActivityType) Reset()
func (*ActivityType) String ¶
func (x *ActivityType) String() string
type Callback ¶
type Callback struct {
// Types that are valid to be assigned to Variant:
//
// *Callback_Nexus_
// *Callback_Internal_
Variant isCallback_Variant `protobuf_oneof:"variant"`
// Links associated with the callback. It can be used to link to underlying resources of the
// callback.
Links []*Link `protobuf:"bytes,100,rep,name=links,proto3" json:"links,omitempty"`
// contains filtered or unexported fields
}
Callback to attach to various events in the system, e.g. workflow run completion.
func (*Callback) Descriptor
deprecated
func (*Callback) GetInternal ¶
func (x *Callback) GetInternal() *Callback_Internal
func (*Callback) GetNexus ¶
func (x *Callback) GetNexus() *Callback_Nexus
func (*Callback) GetVariant ¶
func (x *Callback) GetVariant() isCallback_Variant
func (*Callback) ProtoMessage ¶
func (*Callback) ProtoMessage()
func (*Callback) ProtoReflect ¶
func (x *Callback) ProtoReflect() protoreflect.Message
type Callback_Internal ¶
type Callback_Internal struct {
// Opaque internal data.
Data []byte `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
Callbacks to be delivered internally within the system. This variant is not settable in the API and will be rejected by the service with an INVALID_ARGUMENT error. The only reason that this is exposed is because callbacks are replicated across clusters via the WorkflowExecutionStarted event, which is defined in the public API.
func (*Callback_Internal) Descriptor
deprecated
func (*Callback_Internal) Descriptor() ([]byte, []int)
Deprecated: Use Callback_Internal.ProtoReflect.Descriptor instead.
func (*Callback_Internal) GetData ¶
func (x *Callback_Internal) GetData() []byte
func (*Callback_Internal) ProtoMessage ¶
func (*Callback_Internal) ProtoMessage()
func (*Callback_Internal) ProtoReflect ¶
func (x *Callback_Internal) ProtoReflect() protoreflect.Message
func (*Callback_Internal) Reset ¶
func (x *Callback_Internal) Reset()
func (*Callback_Internal) String ¶
func (x *Callback_Internal) String() string
type Callback_Internal_ ¶
type Callback_Internal_ struct {
Internal *Callback_Internal `protobuf:"bytes,3,opt,name=internal,proto3,oneof"`
}
type Callback_Nexus ¶
type Callback_Nexus struct {
// Callback URL.
Url string `protobuf:"bytes,1,opt,name=url,proto3" json:"url,omitempty"`
// Header to attach to callback request.
Header map[string]string `` /* 139-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*Callback_Nexus) Descriptor
deprecated
func (*Callback_Nexus) Descriptor() ([]byte, []int)
Deprecated: Use Callback_Nexus.ProtoReflect.Descriptor instead.
func (*Callback_Nexus) GetHeader ¶
func (x *Callback_Nexus) GetHeader() map[string]string
func (*Callback_Nexus) GetUrl ¶
func (x *Callback_Nexus) GetUrl() string
func (*Callback_Nexus) ProtoMessage ¶
func (*Callback_Nexus) ProtoMessage()
func (*Callback_Nexus) ProtoReflect ¶
func (x *Callback_Nexus) ProtoReflect() protoreflect.Message
func (*Callback_Nexus) Reset ¶
func (x *Callback_Nexus) Reset()
func (*Callback_Nexus) String ¶
func (x *Callback_Nexus) String() string
type Callback_Nexus_ ¶
type Callback_Nexus_ struct {
Nexus *Callback_Nexus `protobuf:"bytes,2,opt,name=nexus,proto3,oneof"`
}
type DataBlob ¶
type DataBlob struct {
EncodingType v1.EncodingType `` /* 138-byte string literal not displayed */
Data []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
func (*DataBlob) Descriptor
deprecated
func (*DataBlob) GetEncodingType ¶
func (x *DataBlob) GetEncodingType() v1.EncodingType
func (*DataBlob) ProtoMessage ¶
func (*DataBlob) ProtoMessage()
func (*DataBlob) ProtoReflect ¶
func (x *DataBlob) ProtoReflect() protoreflect.Message
type Header ¶
type Header struct {
Fields map[string]*Payload `` /* 139-byte string literal not displayed */
// contains filtered or unexported fields
}
Contains metadata that can be attached to a variety of requests, like starting a workflow, and can be propagated between, for example, workflows and activities.
func (*Header) Descriptor
deprecated
func (*Header) ProtoMessage ¶
func (*Header) ProtoMessage()
func (*Header) ProtoReflect ¶
func (x *Header) ProtoReflect() protoreflect.Message
type Link ¶
type Link struct {
// Types that are valid to be assigned to Variant:
//
// *Link_WorkflowEvent_
// *Link_BatchJob_
// *Link_Activity_
// *Link_NexusOperation_
Variant isLink_Variant `protobuf_oneof:"variant"`
// contains filtered or unexported fields
}
Link can be associated with history events. It might contain information about an external entity related to the history event. For example, workflow A makes a Nexus call that starts workflow B: in this case, a history event in workflow A could contain a Link to the workflow started event in workflow B, and vice-versa.
func (*Link) Descriptor
deprecated
func (*Link) GetActivity ¶
func (x *Link) GetActivity() *Link_Activity
func (*Link) GetBatchJob ¶
func (x *Link) GetBatchJob() *Link_BatchJob
func (*Link) GetNexusOperation ¶
func (x *Link) GetNexusOperation() *Link_NexusOperation
func (*Link) GetVariant ¶
func (x *Link) GetVariant() isLink_Variant
func (*Link) GetWorkflowEvent ¶
func (x *Link) GetWorkflowEvent() *Link_WorkflowEvent
func (*Link) ProtoMessage ¶
func (*Link) ProtoMessage()
func (*Link) ProtoReflect ¶
func (x *Link) ProtoReflect() protoreflect.Message
type Link_Activity ¶
type Link_Activity struct {
Namespace string `protobuf:"bytes,1,opt,name=namespace,proto3" json:"namespace,omitempty"`
ActivityId string `protobuf:"bytes,2,opt,name=activity_id,json=activityId,proto3" json:"activity_id,omitempty"`
RunId string `protobuf:"bytes,3,opt,name=run_id,json=runId,proto3" json:"run_id,omitempty"`
// contains filtered or unexported fields
}
A link to an activity.
func (*Link_Activity) Descriptor
deprecated
func (*Link_Activity) Descriptor() ([]byte, []int)
Deprecated: Use Link_Activity.ProtoReflect.Descriptor instead.
func (*Link_Activity) GetActivityId ¶
func (x *Link_Activity) GetActivityId() string
func (*Link_Activity) GetNamespace ¶
func (x *Link_Activity) GetNamespace() string
func (*Link_Activity) GetRunId ¶
func (x *Link_Activity) GetRunId() string
func (*Link_Activity) ProtoMessage ¶
func (*Link_Activity) ProtoMessage()
func (*Link_Activity) ProtoReflect ¶
func (x *Link_Activity) ProtoReflect() protoreflect.Message
func (*Link_Activity) Reset ¶
func (x *Link_Activity) Reset()
func (*Link_Activity) String ¶
func (x *Link_Activity) String() string
type Link_Activity_ ¶
type Link_Activity_ struct {
Activity *Link_Activity `protobuf:"bytes,3,opt,name=activity,proto3,oneof"`
}
type Link_BatchJob ¶
type Link_BatchJob struct {
JobId string `protobuf:"bytes,1,opt,name=job_id,json=jobId,proto3" json:"job_id,omitempty"`
// contains filtered or unexported fields
}
A link to a built-in batch job. Batch jobs can be used to perform operations on a set of workflows (e.g. terminate, signal, cancel, etc). This link can be put on workflow history events generated by actions taken by a batch job.
func (*Link_BatchJob) Descriptor
deprecated
func (*Link_BatchJob) Descriptor() ([]byte, []int)
Deprecated: Use Link_BatchJob.ProtoReflect.Descriptor instead.
func (*Link_BatchJob) GetJobId ¶
func (x *Link_BatchJob) GetJobId() string
func (*Link_BatchJob) ProtoMessage ¶
func (*Link_BatchJob) ProtoMessage()
func (*Link_BatchJob) ProtoReflect ¶
func (x *Link_BatchJob) ProtoReflect() protoreflect.Message
func (*Link_BatchJob) Reset ¶
func (x *Link_BatchJob) Reset()
func (*Link_BatchJob) String ¶
func (x *Link_BatchJob) String() string
type Link_BatchJob_ ¶
type Link_BatchJob_ struct {
BatchJob *Link_BatchJob `protobuf:"bytes,2,opt,name=batch_job,json=batchJob,proto3,oneof"`
}
type Link_NexusOperation ¶
type Link_NexusOperation struct {
Namespace string `protobuf:"bytes,1,opt,name=namespace,proto3" json:"namespace,omitempty"`
OperationId string `protobuf:"bytes,2,opt,name=operation_id,json=operationId,proto3" json:"operation_id,omitempty"`
RunId string `protobuf:"bytes,3,opt,name=run_id,json=runId,proto3" json:"run_id,omitempty"`
// contains filtered or unexported fields
}
A link to a standalone Nexus operation.
func (*Link_NexusOperation) Descriptor
deprecated
func (*Link_NexusOperation) Descriptor() ([]byte, []int)
Deprecated: Use Link_NexusOperation.ProtoReflect.Descriptor instead.
func (*Link_NexusOperation) GetNamespace ¶
func (x *Link_NexusOperation) GetNamespace() string
func (*Link_NexusOperation) GetOperationId ¶
func (x *Link_NexusOperation) GetOperationId() string
func (*Link_NexusOperation) GetRunId ¶
func (x *Link_NexusOperation) GetRunId() string
func (*Link_NexusOperation) ProtoMessage ¶
func (*Link_NexusOperation) ProtoMessage()
func (*Link_NexusOperation) ProtoReflect ¶
func (x *Link_NexusOperation) ProtoReflect() protoreflect.Message
func (*Link_NexusOperation) Reset ¶
func (x *Link_NexusOperation) Reset()
func (*Link_NexusOperation) String ¶
func (x *Link_NexusOperation) String() string
type Link_NexusOperation_ ¶
type Link_NexusOperation_ struct {
NexusOperation *Link_NexusOperation `protobuf:"bytes,4,opt,name=nexus_operation,json=nexusOperation,proto3,oneof"`
}
type Link_WorkflowEvent ¶
type Link_WorkflowEvent struct {
Namespace string `protobuf:"bytes,1,opt,name=namespace,proto3" json:"namespace,omitempty"`
WorkflowId string `protobuf:"bytes,2,opt,name=workflow_id,json=workflowId,proto3" json:"workflow_id,omitempty"`
RunId string `protobuf:"bytes,3,opt,name=run_id,json=runId,proto3" json:"run_id,omitempty"`
// Additional information about the workflow event.
// Eg: the caller workflow can send the history event details that made the Nexus call.
//
// Types that are valid to be assigned to Reference:
//
// *Link_WorkflowEvent_EventRef
// *Link_WorkflowEvent_RequestIdRef
Reference isLink_WorkflowEvent_Reference `protobuf_oneof:"reference"`
// contains filtered or unexported fields
}
func (*Link_WorkflowEvent) Descriptor
deprecated
func (*Link_WorkflowEvent) Descriptor() ([]byte, []int)
Deprecated: Use Link_WorkflowEvent.ProtoReflect.Descriptor instead.
func (*Link_WorkflowEvent) GetEventRef ¶
func (x *Link_WorkflowEvent) GetEventRef() *Link_WorkflowEvent_EventReference
func (*Link_WorkflowEvent) GetNamespace ¶
func (x *Link_WorkflowEvent) GetNamespace() string
func (*Link_WorkflowEvent) GetReference ¶
func (x *Link_WorkflowEvent) GetReference() isLink_WorkflowEvent_Reference
func (*Link_WorkflowEvent) GetRequestIdRef ¶
func (x *Link_WorkflowEvent) GetRequestIdRef() *Link_WorkflowEvent_RequestIdReference
func (*Link_WorkflowEvent) GetRunId ¶
func (x *Link_WorkflowEvent) GetRunId() string
func (*Link_WorkflowEvent) GetWorkflowId ¶
func (x *Link_WorkflowEvent) GetWorkflowId() string
func (*Link_WorkflowEvent) ProtoMessage ¶
func (*Link_WorkflowEvent) ProtoMessage()
func (*Link_WorkflowEvent) ProtoReflect ¶
func (x *Link_WorkflowEvent) ProtoReflect() protoreflect.Message
func (*Link_WorkflowEvent) Reset ¶
func (x *Link_WorkflowEvent) Reset()
func (*Link_WorkflowEvent) String ¶
func (x *Link_WorkflowEvent) String() string
type Link_WorkflowEvent_ ¶
type Link_WorkflowEvent_ struct {
WorkflowEvent *Link_WorkflowEvent `protobuf:"bytes,1,opt,name=workflow_event,json=workflowEvent,proto3,oneof"`
}
type Link_WorkflowEvent_EventRef ¶
type Link_WorkflowEvent_EventRef struct {
EventRef *Link_WorkflowEvent_EventReference `protobuf:"bytes,100,opt,name=event_ref,json=eventRef,proto3,oneof"`
}
type Link_WorkflowEvent_EventReference ¶
type Link_WorkflowEvent_EventReference struct {
EventId int64 `protobuf:"varint,1,opt,name=event_id,json=eventId,proto3" json:"event_id,omitempty"`
EventType v1.EventType `` /* 126-byte string literal not displayed */
// contains filtered or unexported fields
}
EventReference is a direct reference to a history event through the event ID.
func (*Link_WorkflowEvent_EventReference) Descriptor
deprecated
func (*Link_WorkflowEvent_EventReference) Descriptor() ([]byte, []int)
Deprecated: Use Link_WorkflowEvent_EventReference.ProtoReflect.Descriptor instead.
func (*Link_WorkflowEvent_EventReference) GetEventId ¶
func (x *Link_WorkflowEvent_EventReference) GetEventId() int64
func (*Link_WorkflowEvent_EventReference) GetEventType ¶
func (x *Link_WorkflowEvent_EventReference) GetEventType() v1.EventType
func (*Link_WorkflowEvent_EventReference) ProtoMessage ¶
func (*Link_WorkflowEvent_EventReference) ProtoMessage()
func (*Link_WorkflowEvent_EventReference) ProtoReflect ¶
func (x *Link_WorkflowEvent_EventReference) ProtoReflect() protoreflect.Message
func (*Link_WorkflowEvent_EventReference) Reset ¶
func (x *Link_WorkflowEvent_EventReference) Reset()
func (*Link_WorkflowEvent_EventReference) String ¶
func (x *Link_WorkflowEvent_EventReference) String() string
type Link_WorkflowEvent_RequestIdRef ¶
type Link_WorkflowEvent_RequestIdRef struct {
RequestIdRef *Link_WorkflowEvent_RequestIdReference `protobuf:"bytes,101,opt,name=request_id_ref,json=requestIdRef,proto3,oneof"`
}
type Link_WorkflowEvent_RequestIdReference ¶
type Link_WorkflowEvent_RequestIdReference struct {
RequestId string `protobuf:"bytes,1,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
EventType v1.EventType `` /* 126-byte string literal not displayed */
// contains filtered or unexported fields
}
RequestIdReference is a indirect reference to a history event through the request ID.
func (*Link_WorkflowEvent_RequestIdReference) Descriptor
deprecated
func (*Link_WorkflowEvent_RequestIdReference) Descriptor() ([]byte, []int)
Deprecated: Use Link_WorkflowEvent_RequestIdReference.ProtoReflect.Descriptor instead.
func (*Link_WorkflowEvent_RequestIdReference) GetEventType ¶
func (x *Link_WorkflowEvent_RequestIdReference) GetEventType() v1.EventType
func (*Link_WorkflowEvent_RequestIdReference) GetRequestId ¶
func (x *Link_WorkflowEvent_RequestIdReference) GetRequestId() string
func (*Link_WorkflowEvent_RequestIdReference) ProtoMessage ¶
func (*Link_WorkflowEvent_RequestIdReference) ProtoMessage()
func (*Link_WorkflowEvent_RequestIdReference) ProtoReflect ¶
func (x *Link_WorkflowEvent_RequestIdReference) ProtoReflect() protoreflect.Message
func (*Link_WorkflowEvent_RequestIdReference) Reset ¶
func (x *Link_WorkflowEvent_RequestIdReference) Reset()
func (*Link_WorkflowEvent_RequestIdReference) String ¶
func (x *Link_WorkflowEvent_RequestIdReference) String() string
type Memo ¶
type Memo struct {
Fields map[string]*Payload `` /* 139-byte string literal not displayed */
// contains filtered or unexported fields
}
A user-defined set of *unindexed* fields that are exposed when listing/searching workflows
func (*Memo) Descriptor
deprecated
func (*Memo) ProtoMessage ¶
func (*Memo) ProtoMessage()
func (*Memo) ProtoReflect ¶
func (x *Memo) ProtoReflect() protoreflect.Message
type MeteringMetadata ¶
type MeteringMetadata struct {
// Count of local activities which have begun an execution attempt during this workflow task,
// and whose first attempt occurred in some previous task. This is used for metering
// purposes, and does not affect workflow state.
//
// (-- api-linter: core::0141::forbidden-types=disabled
//
// aip.dev/not-precedent: Negative values make no sense to represent. --)
NonfirstLocalActivityExecutionAttempts uint32 `` /* 183-byte string literal not displayed */
// contains filtered or unexported fields
}
Metadata relevant for metering purposes
func (*MeteringMetadata) Descriptor
deprecated
func (*MeteringMetadata) Descriptor() ([]byte, []int)
Deprecated: Use MeteringMetadata.ProtoReflect.Descriptor instead.
func (*MeteringMetadata) GetNonfirstLocalActivityExecutionAttempts ¶
func (x *MeteringMetadata) GetNonfirstLocalActivityExecutionAttempts() uint32
func (*MeteringMetadata) ProtoMessage ¶
func (*MeteringMetadata) ProtoMessage()
func (*MeteringMetadata) ProtoReflect ¶
func (x *MeteringMetadata) ProtoReflect() protoreflect.Message
func (*MeteringMetadata) Reset ¶
func (x *MeteringMetadata) Reset()
func (*MeteringMetadata) String ¶
func (x *MeteringMetadata) String() string
type OnConflictOptions ¶
type OnConflictOptions struct {
// Attaches the request ID to the running execution.
AttachRequestId bool `protobuf:"varint,1,opt,name=attach_request_id,json=attachRequestId,proto3" json:"attach_request_id,omitempty"`
// Attaches the completion callbacks to the running execution.
AttachCompletionCallbacks bool `` /* 139-byte string literal not displayed */
// Attaches the links to the running execution.
AttachLinks bool `protobuf:"varint,3,opt,name=attach_links,json=attachLinks,proto3" json:"attach_links,omitempty"`
// contains filtered or unexported fields
}
When starting an execution with a conflict policy that uses an existing execution and there is already an existing running execution, OnConflictOptions defines actions to be taken on the existing running execution.
func (*OnConflictOptions) Descriptor
deprecated
func (*OnConflictOptions) Descriptor() ([]byte, []int)
Deprecated: Use OnConflictOptions.ProtoReflect.Descriptor instead.
func (*OnConflictOptions) GetAttachCompletionCallbacks ¶
func (x *OnConflictOptions) GetAttachCompletionCallbacks() bool
func (*OnConflictOptions) GetAttachLinks ¶
func (x *OnConflictOptions) GetAttachLinks() bool
func (*OnConflictOptions) GetAttachRequestId ¶
func (x *OnConflictOptions) GetAttachRequestId() bool
func (*OnConflictOptions) ProtoMessage ¶
func (*OnConflictOptions) ProtoMessage()
func (*OnConflictOptions) ProtoReflect ¶
func (x *OnConflictOptions) ProtoReflect() protoreflect.Message
func (*OnConflictOptions) Reset ¶
func (x *OnConflictOptions) Reset()
func (*OnConflictOptions) String ¶
func (x *OnConflictOptions) String() string
type Payload ¶
type Payload struct {
Metadata map[string][]byte `` /* 143-byte string literal not displayed */
Data []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
// Details about externally stored payloads associated with this payload.
ExternalPayloads []*Payload_ExternalPayloadDetails `protobuf:"bytes,3,rep,name=external_payloads,json=externalPayloads,proto3" json:"external_payloads,omitempty"`
// contains filtered or unexported fields
}
Represents some binary (byte array) data (ex: activity input parameters or workflow result) with metadata which describes this binary data (format, encoding, encryption, etc). Serialization of the data may be user-defined.
func (*Payload) Descriptor
deprecated
func (*Payload) GetExternalPayloads ¶
func (x *Payload) GetExternalPayloads() []*Payload_ExternalPayloadDetails
func (*Payload) GetMetadata ¶
func (*Payload) ProtoMessage ¶
func (*Payload) ProtoMessage()
func (*Payload) ProtoReflect ¶
func (x *Payload) ProtoReflect() protoreflect.Message
type Payload_ExternalPayloadDetails ¶
type Payload_ExternalPayloadDetails struct {
// Size in bytes of the externally stored payload
SizeBytes int64 `protobuf:"varint,1,opt,name=size_bytes,json=sizeBytes,proto3" json:"size_bytes,omitempty"`
// contains filtered or unexported fields
}
Describes an externally stored object referenced by this payload.
func (*Payload_ExternalPayloadDetails) Descriptor
deprecated
func (*Payload_ExternalPayloadDetails) Descriptor() ([]byte, []int)
Deprecated: Use Payload_ExternalPayloadDetails.ProtoReflect.Descriptor instead.
func (*Payload_ExternalPayloadDetails) GetSizeBytes ¶
func (x *Payload_ExternalPayloadDetails) GetSizeBytes() int64
func (*Payload_ExternalPayloadDetails) ProtoMessage ¶
func (*Payload_ExternalPayloadDetails) ProtoMessage()
func (*Payload_ExternalPayloadDetails) ProtoReflect ¶
func (x *Payload_ExternalPayloadDetails) ProtoReflect() protoreflect.Message
func (*Payload_ExternalPayloadDetails) Reset ¶
func (x *Payload_ExternalPayloadDetails) Reset()
func (*Payload_ExternalPayloadDetails) String ¶
func (x *Payload_ExternalPayloadDetails) String() string
type Payloads ¶
type Payloads struct {
Payloads []*Payload `protobuf:"bytes,1,rep,name=payloads,proto3" json:"payloads,omitempty"`
// contains filtered or unexported fields
}
See `Payload`
func (*Payloads) Descriptor
deprecated
func (*Payloads) GetPayloads ¶
func (*Payloads) ProtoMessage ¶
func (*Payloads) ProtoMessage()
func (*Payloads) ProtoReflect ¶
func (x *Payloads) ProtoReflect() protoreflect.Message
type Principal ¶
type Principal struct {
// Low-cardinality category of the principal (e.g., "jwt", "users").
Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
// Identifier within that category (e.g., sub JWT claim, email address).
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Principal is an authenticated caller identity computed by the server from trusted authentication context.
func (*Principal) Descriptor
deprecated
func (*Principal) ProtoMessage ¶
func (*Principal) ProtoMessage()
func (*Principal) ProtoReflect ¶
func (x *Principal) ProtoReflect() protoreflect.Message
type Priority ¶
type Priority struct {
// Priority key is a positive integer from 1 to n, where smaller integers
// correspond to higher priorities (tasks run sooner). In general, tasks in
// a queue should be processed in close to priority order, although small
// deviations are possible.
//
// The maximum priority value (minimum priority) is determined by server
// configuration, and defaults to 5.
//
// If priority is not present (or zero), then the effective priority will be
// the default priority, which is calculated by (min+max)/2. With the
// default max of 5, and min of 1, that comes out to 3.
PriorityKey int32 `protobuf:"varint,1,opt,name=priority_key,json=priorityKey,proto3" json:"priority_key,omitempty"`
// Fairness key is a short string that's used as a key for a fairness
// balancing mechanism. It may correspond to a tenant id, or to a fixed
// string like "high" or "low". The default is the empty string.
//
// The fairness mechanism attempts to dispatch tasks for a given key in
// proportion to its weight. For example, using a thousand distinct tenant
// ids, each with a weight of 1.0 (the default) will result in each tenant
// getting a roughly equal share of task dispatch throughput.
//
// (Note: this does not imply equal share of worker capacity! Fairness
// decisions are made based on queue statistics, not
// current worker load.)
//
// As another example, using keys "high" and "low" with weight 9.0 and 1.0
// respectively will prefer dispatching "high" tasks over "low" tasks at a
// 9:1 ratio, while allowing either key to use all worker capacity if the
// other is not present.
//
// All fairness mechanisms, including rate limits, are best-effort and
// probabilistic. The results may not match what a "perfect" algorithm with
// infinite resources would produce. The more unique keys are used, the less
// accurate the results will be.
//
// Fairness keys are limited to 64 bytes.
FairnessKey string `protobuf:"bytes,2,opt,name=fairness_key,json=fairnessKey,proto3" json:"fairness_key,omitempty"`
// Fairness weight for a task can come from multiple sources for
// flexibility. From highest to lowest precedence:
// 1. Weights for a small set of keys can be overridden in task queue
// configuration with an API.
// 2. It can be attached to the workflow/activity in this field.
// 3. The default weight of 1.0 will be used.
//
// Weight values are clamped to the range [0.001, 1000].
FairnessWeight float32 `protobuf:"fixed32,3,opt,name=fairness_weight,json=fairnessWeight,proto3" json:"fairness_weight,omitempty"`
// contains filtered or unexported fields
}
Priority contains metadata that controls relative ordering of task processing when tasks are backed up in a queue. Initially, Priority will be used in matching (workflow and activity) task queues. Later it may be used in history task queues and in rate limiting decisions.
Priority is attached to workflows and activities. By default, activities inherit Priority from the workflow that created them, but may override fields when an activity is started or modified.
Despite being named "Priority", this message also contains fields that control "fairness" mechanisms.
For all fields, the field not present or equal to zero/empty string means to inherit the value from the calling workflow, or if there is no calling workflow, then use the default value.
For all fields other than fairness_key, the zero value isn't meaningful so there's no confusion between inherit/default and a meaningful value. For fairness_key, the empty string will be interpreted as "inherit". This means that if a workflow has a non-empty fairness key, you can't override the fairness key of its activity to the empty string.
The overall semantics of Priority are:
- First, consider "priority": higher priority (lower number) goes first.
- Then, consider fairness: try to dispatch tasks for different fairness keys in proportion to their weight.
Applications may use any subset of mechanisms that are useful to them and leave the other fields to use default values.
Not all queues in the system may support the "full" semantics of all priority fields. (Currently only support in matching task queues is planned.)
func (*Priority) Descriptor
deprecated
func (*Priority) GetFairnessKey ¶
func (*Priority) GetFairnessWeight ¶
func (*Priority) GetPriorityKey ¶
func (*Priority) ProtoMessage ¶
func (*Priority) ProtoMessage()
func (*Priority) ProtoReflect ¶
func (x *Priority) ProtoReflect() protoreflect.Message
type ResetOptions ¶
type ResetOptions struct {
// Which workflow task to reset to.
//
// Types that are valid to be assigned to Target:
//
// *ResetOptions_FirstWorkflowTask
// *ResetOptions_LastWorkflowTask
// *ResetOptions_WorkflowTaskId
// *ResetOptions_BuildId
Target isResetOptions_Target `protobuf_oneof:"target"`
// Deprecated. Use `options`.
// Default: RESET_REAPPLY_TYPE_SIGNAL
//
// Deprecated: Marked as deprecated in temporal/api_next/common/v1/message.proto.
ResetReapplyType v1.ResetReapplyType `` /* 157-byte string literal not displayed */
// If true, limit the reset to only within the current run. (Applies to build_id targets and
// possibly others in the future.)
CurrentRunOnly bool `protobuf:"varint,11,opt,name=current_run_only,json=currentRunOnly,proto3" json:"current_run_only,omitempty"`
// Event types not to be reapplied
ResetReapplyExcludeTypes []v1.ResetReapplyExcludeType `` /* 197-byte string literal not displayed */
// contains filtered or unexported fields
}
Describes where and how to reset a workflow, used for batch reset currently and may be used for single-workflow reset later.
func (*ResetOptions) Descriptor
deprecated
func (*ResetOptions) Descriptor() ([]byte, []int)
Deprecated: Use ResetOptions.ProtoReflect.Descriptor instead.
func (*ResetOptions) GetBuildId ¶
func (x *ResetOptions) GetBuildId() string
func (*ResetOptions) GetCurrentRunOnly ¶
func (x *ResetOptions) GetCurrentRunOnly() bool
func (*ResetOptions) GetFirstWorkflowTask ¶
func (x *ResetOptions) GetFirstWorkflowTask() *emptypb.Empty
func (*ResetOptions) GetLastWorkflowTask ¶
func (x *ResetOptions) GetLastWorkflowTask() *emptypb.Empty
func (*ResetOptions) GetResetReapplyExcludeTypes ¶
func (x *ResetOptions) GetResetReapplyExcludeTypes() []v1.ResetReapplyExcludeType
func (*ResetOptions) GetResetReapplyType
deprecated
func (x *ResetOptions) GetResetReapplyType() v1.ResetReapplyType
Deprecated: Marked as deprecated in temporal/api_next/common/v1/message.proto.
func (*ResetOptions) GetTarget ¶
func (x *ResetOptions) GetTarget() isResetOptions_Target
func (*ResetOptions) GetWorkflowTaskId ¶
func (x *ResetOptions) GetWorkflowTaskId() int64
func (*ResetOptions) ProtoMessage ¶
func (*ResetOptions) ProtoMessage()
func (*ResetOptions) ProtoReflect ¶
func (x *ResetOptions) ProtoReflect() protoreflect.Message
func (*ResetOptions) Reset ¶
func (x *ResetOptions) Reset()
func (*ResetOptions) String ¶
func (x *ResetOptions) String() string
type ResetOptions_BuildId ¶
type ResetOptions_BuildId struct {
// Resets to the first workflow task processed by this build id.
// If the workflow was not processed by the build id, or the workflow task can't be
// determined, no reset will be performed.
// Note that by default, this reset is allowed to be to a prior run in a chain of
// continue-as-new.
BuildId string `protobuf:"bytes,4,opt,name=build_id,json=buildId,proto3,oneof"`
}
type ResetOptions_WorkflowTaskId ¶
type ResetOptions_WorkflowTaskId struct {
// The id of a specific `WORKFLOW_TASK_COMPLETED`,`WORKFLOW_TASK_TIMED_OUT`, `WORKFLOW_TASK_FAILED`, or
// `WORKFLOW_TASK_STARTED` event to reset to.
// Note that this option doesn't make sense when used as part of a batch request.
WorkflowTaskId int64 `protobuf:"varint,3,opt,name=workflow_task_id,json=workflowTaskId,proto3,oneof"`
}
type RetryPolicy ¶
type RetryPolicy struct {
// Interval of the first retry. If retryBackoffCoefficient is 1.0 then it is used for all retries.
InitialInterval *durationpb.Duration `protobuf:"bytes,1,opt,name=initial_interval,json=initialInterval,proto3" json:"initial_interval,omitempty"`
// Coefficient used to calculate the next retry interval.
// The next retry interval is previous interval multiplied by the coefficient.
// Must be 1 or larger.
BackoffCoefficient float64 `protobuf:"fixed64,2,opt,name=backoff_coefficient,json=backoffCoefficient,proto3" json:"backoff_coefficient,omitempty"`
// Maximum interval between retries. Exponential backoff leads to interval increase.
// This value is the cap of the increase. Default is 100x of the initial interval.
MaximumInterval *durationpb.Duration `protobuf:"bytes,3,opt,name=maximum_interval,json=maximumInterval,proto3" json:"maximum_interval,omitempty"`
// Maximum number of attempts. When exceeded the retries stop even if not expired yet.
// 1 disables retries. 0 means unlimited (up to the timeouts)
MaximumAttempts int32 `protobuf:"varint,4,opt,name=maximum_attempts,json=maximumAttempts,proto3" json:"maximum_attempts,omitempty"`
// Non-Retryable errors types. Will stop retrying if the error type matches this list. Note that
// this is not a substring match, the error *type* (not message) must match exactly.
NonRetryableErrorTypes []string `` /* 131-byte string literal not displayed */
// contains filtered or unexported fields
}
How retries ought to be handled, usable by both workflows and activities
func (*RetryPolicy) Descriptor
deprecated
func (*RetryPolicy) Descriptor() ([]byte, []int)
Deprecated: Use RetryPolicy.ProtoReflect.Descriptor instead.
func (*RetryPolicy) GetBackoffCoefficient ¶
func (x *RetryPolicy) GetBackoffCoefficient() float64
func (*RetryPolicy) GetInitialInterval ¶
func (x *RetryPolicy) GetInitialInterval() *durationpb.Duration
func (*RetryPolicy) GetMaximumAttempts ¶
func (x *RetryPolicy) GetMaximumAttempts() int32
func (*RetryPolicy) GetMaximumInterval ¶
func (x *RetryPolicy) GetMaximumInterval() *durationpb.Duration
func (*RetryPolicy) GetNonRetryableErrorTypes ¶
func (x *RetryPolicy) GetNonRetryableErrorTypes() []string
func (*RetryPolicy) ProtoMessage ¶
func (*RetryPolicy) ProtoMessage()
func (*RetryPolicy) ProtoReflect ¶
func (x *RetryPolicy) ProtoReflect() protoreflect.Message
func (*RetryPolicy) Reset ¶
func (x *RetryPolicy) Reset()
func (*RetryPolicy) String ¶
func (x *RetryPolicy) String() string
type SearchAttributes ¶
type SearchAttributes struct {
IndexedFields map[string]*Payload `` /* 174-byte string literal not displayed */
// contains filtered or unexported fields
}
A user-defined set of *indexed* fields that are used/exposed when listing/searching workflows. The payload is not serialized in a user-defined way.
func (*SearchAttributes) Descriptor
deprecated
func (*SearchAttributes) Descriptor() ([]byte, []int)
Deprecated: Use SearchAttributes.ProtoReflect.Descriptor instead.
func (*SearchAttributes) GetIndexedFields ¶
func (x *SearchAttributes) GetIndexedFields() map[string]*Payload
func (*SearchAttributes) ProtoMessage ¶
func (*SearchAttributes) ProtoMessage()
func (*SearchAttributes) ProtoReflect ¶
func (x *SearchAttributes) ProtoReflect() protoreflect.Message
func (*SearchAttributes) Reset ¶
func (x *SearchAttributes) Reset()
func (*SearchAttributes) String ¶
func (x *SearchAttributes) String() string
type WorkerSelector ¶
type WorkerSelector struct {
// Options are:
// - query (will be used as query to ListWorkers, same format as in ListWorkersRequest.query)
// - task queue (just a shortcut. Same as query=' "TaskQueue"="my-task-queue" ')
// - etc.
// All but 'query' are shortcuts, can be replaced with a query, but it is not convenient.
//
// string query = 5;
// string task_queue = 6;
// ...
//
// Types that are valid to be assigned to Selector:
//
// *WorkerSelector_WorkerInstanceKey
Selector isWorkerSelector_Selector `protobuf_oneof:"selector"`
// contains filtered or unexported fields
}
This is used to send commands to a specific worker or a group of workers. Right now, it is used to send commands to a specific worker instance. Will be extended to be able to send command to multiple workers.
func (*WorkerSelector) Descriptor
deprecated
func (*WorkerSelector) Descriptor() ([]byte, []int)
Deprecated: Use WorkerSelector.ProtoReflect.Descriptor instead.
func (*WorkerSelector) GetSelector ¶
func (x *WorkerSelector) GetSelector() isWorkerSelector_Selector
func (*WorkerSelector) GetWorkerInstanceKey ¶
func (x *WorkerSelector) GetWorkerInstanceKey() string
func (*WorkerSelector) ProtoMessage ¶
func (*WorkerSelector) ProtoMessage()
func (*WorkerSelector) ProtoReflect ¶
func (x *WorkerSelector) ProtoReflect() protoreflect.Message
func (*WorkerSelector) Reset ¶
func (x *WorkerSelector) Reset()
func (*WorkerSelector) String ¶
func (x *WorkerSelector) String() string
type WorkerSelector_WorkerInstanceKey ¶
type WorkerSelector_WorkerInstanceKey struct {
// Worker instance key to which the command should be sent.
WorkerInstanceKey string `protobuf:"bytes,1,opt,name=worker_instance_key,json=workerInstanceKey,proto3,oneof"`
}
type WorkerVersionCapabilities ¶
type WorkerVersionCapabilities struct {
// An opaque whole-worker identifier
BuildId string `protobuf:"bytes,1,opt,name=build_id,json=buildId,proto3" json:"build_id,omitempty"`
// If set, the worker is opting in to worker versioning, and wishes to only receive appropriate
// tasks.
UseVersioning bool `protobuf:"varint,2,opt,name=use_versioning,json=useVersioning,proto3" json:"use_versioning,omitempty"`
// Must be sent if user has set a deployment series name (versioning-3).
DeploymentSeriesName string `protobuf:"bytes,4,opt,name=deployment_series_name,json=deploymentSeriesName,proto3" json:"deployment_series_name,omitempty"`
// contains filtered or unexported fields
}
Identifies the version that a worker is compatible with when polling or identifying itself, and whether or not this worker is opting into the build-id based versioning feature. This is used by matching to determine which workers ought to receive what tasks. Deprecated. Use WorkerDeploymentOptions instead.
func (*WorkerVersionCapabilities) Descriptor
deprecated
func (*WorkerVersionCapabilities) Descriptor() ([]byte, []int)
Deprecated: Use WorkerVersionCapabilities.ProtoReflect.Descriptor instead.
func (*WorkerVersionCapabilities) GetBuildId ¶
func (x *WorkerVersionCapabilities) GetBuildId() string
func (*WorkerVersionCapabilities) GetDeploymentSeriesName ¶
func (x *WorkerVersionCapabilities) GetDeploymentSeriesName() string
func (*WorkerVersionCapabilities) GetUseVersioning ¶
func (x *WorkerVersionCapabilities) GetUseVersioning() bool
func (*WorkerVersionCapabilities) ProtoMessage ¶
func (*WorkerVersionCapabilities) ProtoMessage()
func (*WorkerVersionCapabilities) ProtoReflect ¶
func (x *WorkerVersionCapabilities) ProtoReflect() protoreflect.Message
func (*WorkerVersionCapabilities) Reset ¶
func (x *WorkerVersionCapabilities) Reset()
func (*WorkerVersionCapabilities) String ¶
func (x *WorkerVersionCapabilities) String() string
type WorkerVersionStamp ¶
type WorkerVersionStamp struct {
// An opaque whole-worker identifier. Replaces the deprecated `binary_checksum` field when this
// message is included in requests which previously used that.
BuildId string `protobuf:"bytes,1,opt,name=build_id,json=buildId,proto3" json:"build_id,omitempty"`
// If set, the worker is opting in to worker versioning. Otherwise, this is used only as a
// marker for workflow reset points and the BuildIDs search attribute.
UseVersioning bool `protobuf:"varint,3,opt,name=use_versioning,json=useVersioning,proto3" json:"use_versioning,omitempty"`
// contains filtered or unexported fields
}
Deprecated. This message is replaced with `Deployment` and `VersioningBehavior`. Identifies the version(s) of a worker that processed a task
func (*WorkerVersionStamp) Descriptor
deprecated
func (*WorkerVersionStamp) Descriptor() ([]byte, []int)
Deprecated: Use WorkerVersionStamp.ProtoReflect.Descriptor instead.
func (*WorkerVersionStamp) GetBuildId ¶
func (x *WorkerVersionStamp) GetBuildId() string
func (*WorkerVersionStamp) GetUseVersioning ¶
func (x *WorkerVersionStamp) GetUseVersioning() bool
func (*WorkerVersionStamp) ProtoMessage ¶
func (*WorkerVersionStamp) ProtoMessage()
func (*WorkerVersionStamp) ProtoReflect ¶
func (x *WorkerVersionStamp) ProtoReflect() protoreflect.Message
func (*WorkerVersionStamp) Reset ¶
func (x *WorkerVersionStamp) Reset()
func (*WorkerVersionStamp) String ¶
func (x *WorkerVersionStamp) String() string
type WorkflowExecution ¶
type WorkflowExecution struct {
WorkflowId string `protobuf:"bytes,1,opt,name=workflow_id,json=workflowId,proto3" json:"workflow_id,omitempty"`
RunId string `protobuf:"bytes,2,opt,name=run_id,json=runId,proto3" json:"run_id,omitempty"`
// contains filtered or unexported fields
}
Identifies a specific workflow within a namespace. Practically speaking, because run_id is a uuid, a workflow execution is globally unique. Note that many commands allow specifying an empty run id as a way of saying "target the latest run of the workflow".
func (*WorkflowExecution) Descriptor
deprecated
func (*WorkflowExecution) Descriptor() ([]byte, []int)
Deprecated: Use WorkflowExecution.ProtoReflect.Descriptor instead.
func (*WorkflowExecution) GetRunId ¶
func (x *WorkflowExecution) GetRunId() string
func (*WorkflowExecution) GetWorkflowId ¶
func (x *WorkflowExecution) GetWorkflowId() string
func (*WorkflowExecution) ProtoMessage ¶
func (*WorkflowExecution) ProtoMessage()
func (*WorkflowExecution) ProtoReflect ¶
func (x *WorkflowExecution) ProtoReflect() protoreflect.Message
func (*WorkflowExecution) Reset ¶
func (x *WorkflowExecution) Reset()
func (*WorkflowExecution) String ¶
func (x *WorkflowExecution) String() string
type WorkflowType ¶
type WorkflowType struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Represents the identifier used by a workflow author to define the workflow. Typically, the name of a function. This is sometimes referred to as the workflow's "name"
func (*WorkflowType) Descriptor
deprecated
func (*WorkflowType) Descriptor() ([]byte, []int)
Deprecated: Use WorkflowType.ProtoReflect.Descriptor instead.
func (*WorkflowType) GetName ¶
func (x *WorkflowType) GetName() string
func (*WorkflowType) ProtoMessage ¶
func (*WorkflowType) ProtoMessage()
func (*WorkflowType) ProtoReflect ¶
func (x *WorkflowType) ProtoReflect() protoreflect.Message
func (*WorkflowType) Reset ¶
func (x *WorkflowType) Reset()
func (*WorkflowType) String ¶
func (x *WorkflowType) String() string