Documentation
¶
Index ¶
- Variables
- type BuildIdAssignmentRule
- func (*BuildIdAssignmentRule) Descriptor() ([]byte, []int)deprecated
- func (x *BuildIdAssignmentRule) GetPercentageRamp() *RampByPercentage
- func (x *BuildIdAssignmentRule) GetRamp() isBuildIdAssignmentRule_Ramp
- func (x *BuildIdAssignmentRule) GetTargetBuildId() string
- func (*BuildIdAssignmentRule) ProtoMessage()
- func (x *BuildIdAssignmentRule) ProtoReflect() protoreflect.Message
- func (x *BuildIdAssignmentRule) Reset()
- func (x *BuildIdAssignmentRule) String() string
- type BuildIdAssignmentRule_PercentageRamp
- type BuildIdReachability
- func (*BuildIdReachability) Descriptor() ([]byte, []int)deprecated
- func (x *BuildIdReachability) GetBuildId() string
- func (x *BuildIdReachability) GetTaskQueueReachability() []*TaskQueueReachability
- func (*BuildIdReachability) ProtoMessage()
- func (x *BuildIdReachability) ProtoReflect() protoreflect.Message
- func (x *BuildIdReachability) Reset()
- func (x *BuildIdReachability) String() string
- type CompatibleBuildIdRedirectRule
- func (*CompatibleBuildIdRedirectRule) Descriptor() ([]byte, []int)deprecated
- func (x *CompatibleBuildIdRedirectRule) GetSourceBuildId() string
- func (x *CompatibleBuildIdRedirectRule) GetTargetBuildId() string
- func (*CompatibleBuildIdRedirectRule) ProtoMessage()
- func (x *CompatibleBuildIdRedirectRule) ProtoReflect() protoreflect.Message
- func (x *CompatibleBuildIdRedirectRule) Reset()
- func (x *CompatibleBuildIdRedirectRule) String() string
- type CompatibleVersionSet
- func (*CompatibleVersionSet) Descriptor() ([]byte, []int)deprecated
- func (x *CompatibleVersionSet) GetBuildIds() []string
- func (*CompatibleVersionSet) ProtoMessage()
- func (x *CompatibleVersionSet) ProtoReflect() protoreflect.Message
- func (x *CompatibleVersionSet) Reset()
- func (x *CompatibleVersionSet) String() string
- type ConfigMetadata
- func (*ConfigMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *ConfigMetadata) GetReason() string
- func (x *ConfigMetadata) GetUpdateIdentity() string
- func (x *ConfigMetadata) GetUpdateTime() *timestamppb.Timestamp
- func (*ConfigMetadata) ProtoMessage()
- func (x *ConfigMetadata) ProtoReflect() protoreflect.Message
- func (x *ConfigMetadata) Reset()
- func (x *ConfigMetadata) String() string
- type PollerGroupInfo
- func (*PollerGroupInfo) Descriptor() ([]byte, []int)deprecated
- func (x *PollerGroupInfo) GetId() string
- func (x *PollerGroupInfo) GetWeight() float32
- func (*PollerGroupInfo) ProtoMessage()
- func (x *PollerGroupInfo) ProtoReflect() protoreflect.Message
- func (x *PollerGroupInfo) Reset()
- func (x *PollerGroupInfo) String() string
- type PollerInfo
- func (*PollerInfo) Descriptor() ([]byte, []int)deprecated
- func (x *PollerInfo) GetDeploymentOptions() *v11.WorkerDeploymentOptions
- func (x *PollerInfo) GetIdentity() string
- func (x *PollerInfo) GetLastAccessTime() *timestamppb.Timestamp
- func (x *PollerInfo) GetRatePerSecond() float64
- func (x *PollerInfo) GetWorkerVersionCapabilities() *v12.WorkerVersionCapabilitiesdeprecated
- func (*PollerInfo) ProtoMessage()
- func (x *PollerInfo) ProtoReflect() protoreflect.Message
- func (x *PollerInfo) Reset()
- func (x *PollerInfo) String() string
- type PollerScalingDecision
- func (*PollerScalingDecision) Descriptor() ([]byte, []int)deprecated
- func (x *PollerScalingDecision) GetPollRequestDeltaSuggestion() int32
- func (*PollerScalingDecision) ProtoMessage()
- func (x *PollerScalingDecision) ProtoReflect() protoreflect.Message
- func (x *PollerScalingDecision) Reset()
- func (x *PollerScalingDecision) String() string
- type RampByPercentage
- type RateLimit
- type RateLimitConfig
- func (*RateLimitConfig) Descriptor() ([]byte, []int)deprecated
- func (x *RateLimitConfig) GetMetadata() *ConfigMetadata
- func (x *RateLimitConfig) GetRateLimit() *RateLimit
- func (*RateLimitConfig) ProtoMessage()
- func (x *RateLimitConfig) ProtoReflect() protoreflect.Message
- func (x *RateLimitConfig) Reset()
- func (x *RateLimitConfig) String() string
- type StickyExecutionAttributes
- func (*StickyExecutionAttributes) Descriptor() ([]byte, []int)deprecated
- func (x *StickyExecutionAttributes) GetScheduleToStartTimeout() *durationpb.Duration
- func (x *StickyExecutionAttributes) GetWorkerTaskQueue() *TaskQueue
- func (*StickyExecutionAttributes) ProtoMessage()
- func (x *StickyExecutionAttributes) ProtoReflect() protoreflect.Message
- func (x *StickyExecutionAttributes) Reset()
- func (x *StickyExecutionAttributes) String() string
- type TaskIdBlock
- type TaskQueue
- func (*TaskQueue) Descriptor() ([]byte, []int)deprecated
- func (x *TaskQueue) GetKind() v1.TaskQueueKind
- func (x *TaskQueue) GetName() string
- func (x *TaskQueue) GetNormalName() string
- func (*TaskQueue) ProtoMessage()
- func (x *TaskQueue) ProtoReflect() protoreflect.Message
- func (x *TaskQueue) Reset()
- func (x *TaskQueue) String() string
- type TaskQueueConfig
- func (*TaskQueueConfig) Descriptor() ([]byte, []int)deprecated
- func (x *TaskQueueConfig) GetFairnessKeysRateLimitDefault() *RateLimitConfig
- func (x *TaskQueueConfig) GetFairnessWeightOverrides() map[string]float32
- func (x *TaskQueueConfig) GetQueueRateLimit() *RateLimitConfig
- func (*TaskQueueConfig) ProtoMessage()
- func (x *TaskQueueConfig) ProtoReflect() protoreflect.Message
- func (x *TaskQueueConfig) Reset()
- func (x *TaskQueueConfig) String() string
- type TaskQueueMetadata
- func (*TaskQueueMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *TaskQueueMetadata) GetMaxTasksPerSecond() *wrapperspb.DoubleValue
- func (*TaskQueueMetadata) ProtoMessage()
- func (x *TaskQueueMetadata) ProtoReflect() protoreflect.Message
- func (x *TaskQueueMetadata) Reset()
- func (x *TaskQueueMetadata) String() string
- type TaskQueuePartitionMetadata
- func (*TaskQueuePartitionMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *TaskQueuePartitionMetadata) GetKey() string
- func (x *TaskQueuePartitionMetadata) GetOwnerHostName() string
- func (*TaskQueuePartitionMetadata) ProtoMessage()
- func (x *TaskQueuePartitionMetadata) ProtoReflect() protoreflect.Message
- func (x *TaskQueuePartitionMetadata) Reset()
- func (x *TaskQueuePartitionMetadata) String() string
- type TaskQueueReachability
- func (*TaskQueueReachability) Descriptor() ([]byte, []int)deprecated
- func (x *TaskQueueReachability) GetReachability() []v1.TaskReachability
- func (x *TaskQueueReachability) GetTaskQueue() string
- func (*TaskQueueReachability) ProtoMessage()
- func (x *TaskQueueReachability) ProtoReflect() protoreflect.Message
- func (x *TaskQueueReachability) Reset()
- func (x *TaskQueueReachability) String() string
- type TaskQueueStats
- func (*TaskQueueStats) Descriptor() ([]byte, []int)deprecated
- func (x *TaskQueueStats) GetApproximateBacklogAge() *durationpb.Duration
- func (x *TaskQueueStats) GetApproximateBacklogCount() int64
- func (x *TaskQueueStats) GetTasksAddRate() float32
- func (x *TaskQueueStats) GetTasksDispatchRate() float32
- func (*TaskQueueStats) ProtoMessage()
- func (x *TaskQueueStats) ProtoReflect() protoreflect.Message
- func (x *TaskQueueStats) Reset()
- func (x *TaskQueueStats) String() string
- type TaskQueueStatus
- func (*TaskQueueStatus) Descriptor() ([]byte, []int)deprecated
- func (x *TaskQueueStatus) GetAckLevel() int64
- func (x *TaskQueueStatus) GetBacklogCountHint() int64
- func (x *TaskQueueStatus) GetRatePerSecond() float64
- func (x *TaskQueueStatus) GetReadLevel() int64
- func (x *TaskQueueStatus) GetTaskIdBlock() *TaskIdBlock
- func (*TaskQueueStatus) ProtoMessage()
- func (x *TaskQueueStatus) ProtoReflect() protoreflect.Message
- func (x *TaskQueueStatus) Reset()
- func (x *TaskQueueStatus) String() string
- type TaskQueueTypeInfo
- func (*TaskQueueTypeInfo) Descriptor() ([]byte, []int)deprecated
- func (x *TaskQueueTypeInfo) GetPollers() []*PollerInfo
- func (x *TaskQueueTypeInfo) GetStats() *TaskQueueStats
- func (*TaskQueueTypeInfo) ProtoMessage()
- func (x *TaskQueueTypeInfo) ProtoReflect() protoreflect.Message
- func (x *TaskQueueTypeInfo) Reset()
- func (x *TaskQueueTypeInfo) String() string
- type TaskQueueVersionInfo
- func (*TaskQueueVersionInfo) Descriptor() ([]byte, []int)deprecated
- func (x *TaskQueueVersionInfo) GetTaskReachability() v1.BuildIdTaskReachability
- func (x *TaskQueueVersionInfo) GetTypesInfo() map[int32]*TaskQueueTypeInfo
- func (*TaskQueueVersionInfo) ProtoMessage()
- func (x *TaskQueueVersionInfo) ProtoReflect() protoreflect.Message
- func (x *TaskQueueVersionInfo) Reset()
- func (x *TaskQueueVersionInfo) String() string
- type TaskQueueVersionSelection
- func (*TaskQueueVersionSelection) Descriptor() ([]byte, []int)deprecated
- func (x *TaskQueueVersionSelection) GetAllActive() bool
- func (x *TaskQueueVersionSelection) GetBuildIds() []string
- func (x *TaskQueueVersionSelection) GetUnversioned() bool
- func (*TaskQueueVersionSelection) ProtoMessage()
- func (x *TaskQueueVersionSelection) ProtoReflect() protoreflect.Message
- func (x *TaskQueueVersionSelection) Reset()
- func (x *TaskQueueVersionSelection) String() string
- type TaskQueueVersioningInfo
- func (*TaskQueueVersioningInfo) Descriptor() ([]byte, []int)deprecated
- func (x *TaskQueueVersioningInfo) GetCurrentDeploymentVersion() *v11.WorkerDeploymentVersion
- func (x *TaskQueueVersioningInfo) GetCurrentVersion() stringdeprecated
- func (x *TaskQueueVersioningInfo) GetRampingDeploymentVersion() *v11.WorkerDeploymentVersion
- func (x *TaskQueueVersioningInfo) GetRampingVersion() stringdeprecated
- func (x *TaskQueueVersioningInfo) GetRampingVersionPercentage() float32
- func (x *TaskQueueVersioningInfo) GetUpdateTime() *timestamppb.Timestamp
- func (*TaskQueueVersioningInfo) ProtoMessage()
- func (x *TaskQueueVersioningInfo) ProtoReflect() protoreflect.Message
- func (x *TaskQueueVersioningInfo) Reset()
- func (x *TaskQueueVersioningInfo) String() string
- type TimestampedBuildIdAssignmentRule
- func (*TimestampedBuildIdAssignmentRule) Descriptor() ([]byte, []int)deprecated
- func (x *TimestampedBuildIdAssignmentRule) GetCreateTime() *timestamppb.Timestamp
- func (x *TimestampedBuildIdAssignmentRule) GetRule() *BuildIdAssignmentRule
- func (*TimestampedBuildIdAssignmentRule) ProtoMessage()
- func (x *TimestampedBuildIdAssignmentRule) ProtoReflect() protoreflect.Message
- func (x *TimestampedBuildIdAssignmentRule) Reset()
- func (x *TimestampedBuildIdAssignmentRule) String() string
- type TimestampedCompatibleBuildIdRedirectRule
- func (*TimestampedCompatibleBuildIdRedirectRule) Descriptor() ([]byte, []int)deprecated
- func (x *TimestampedCompatibleBuildIdRedirectRule) GetCreateTime() *timestamppb.Timestamp
- func (x *TimestampedCompatibleBuildIdRedirectRule) GetRule() *CompatibleBuildIdRedirectRule
- func (*TimestampedCompatibleBuildIdRedirectRule) ProtoMessage()
- func (x *TimestampedCompatibleBuildIdRedirectRule) ProtoReflect() protoreflect.Message
- func (x *TimestampedCompatibleBuildIdRedirectRule) Reset()
- func (x *TimestampedCompatibleBuildIdRedirectRule) String() string
Constants ¶
This section is empty.
Variables ¶
var File_temporal_api_next_taskqueue_v1_message_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type BuildIdAssignmentRule ¶
type BuildIdAssignmentRule struct {
TargetBuildId string `protobuf:"bytes,1,opt,name=target_build_id,json=targetBuildId,proto3" json:"target_build_id,omitempty"`
// If a ramp is provided, this rule will be applied only to a sample of
// tasks according to the provided percentage.
// This option can be used only on "terminal" Build IDs (the ones not used
// as source in any redirect rules).
//
// Types that are valid to be assigned to Ramp:
//
// *BuildIdAssignmentRule_PercentageRamp
Ramp isBuildIdAssignmentRule_Ramp `protobuf_oneof:"ramp"`
// contains filtered or unexported fields
}
Assignment rules are applied to *new* Workflow and Activity executions at schedule time to assign them to a Build ID.
Assignment rules will not be used in the following cases:
- Child Workflows or Continue-As-New Executions who inherit their parent/previous Workflow's assigned Build ID (by setting the `inherit_build_id` flag - default behavior in SDKs when the same Task Queue is used.)
- An Activity that inherits the assigned Build ID of its Workflow (by setting the `use_workflow_build_id` flag - default behavior in SDKs when the same Task Queue is used.)
In absence of (applicable) redirect rules (`CompatibleBuildIdRedirectRule`s) the task will be dispatched to Workers of the Build ID determined by the assignment rules (or inherited). Otherwise, the final Build ID will be determined by the redirect rules.
Once a Workflow completes its first Workflow Task in a particular Build ID it stays in that Build ID regardless of changes to assignment rules. Redirect rules can be used to move the workflow to another compatible Build ID.
When using Worker Versioning on a Task Queue, in the steady state, there should typically be a single assignment rule to send all new executions to the latest Build ID. Existence of at least one such "unconditional" rule at all times is enforces by the system, unless the `force` flag is used by the user when replacing/deleting these rules (for exceptional cases).
During a deployment, one or more additional rules can be added to assign a subset of the tasks to a new Build ID based on a "ramp percentage".
When there are multiple assignment rules for a Task Queue, the rules are evaluated in order, starting from index 0. The first applicable rule will be applied and the rest will be ignored.
In the event that no assignment rule is applicable on a task (or the Task Queue is simply not versioned), the tasks will be dispatched to an unversioned Worker.
func (*BuildIdAssignmentRule) Descriptor
deprecated
func (*BuildIdAssignmentRule) Descriptor() ([]byte, []int)
Deprecated: Use BuildIdAssignmentRule.ProtoReflect.Descriptor instead.
func (*BuildIdAssignmentRule) GetPercentageRamp ¶
func (x *BuildIdAssignmentRule) GetPercentageRamp() *RampByPercentage
func (*BuildIdAssignmentRule) GetRamp ¶
func (x *BuildIdAssignmentRule) GetRamp() isBuildIdAssignmentRule_Ramp
func (*BuildIdAssignmentRule) GetTargetBuildId ¶
func (x *BuildIdAssignmentRule) GetTargetBuildId() string
func (*BuildIdAssignmentRule) ProtoMessage ¶
func (*BuildIdAssignmentRule) ProtoMessage()
func (*BuildIdAssignmentRule) ProtoReflect ¶
func (x *BuildIdAssignmentRule) ProtoReflect() protoreflect.Message
func (*BuildIdAssignmentRule) Reset ¶
func (x *BuildIdAssignmentRule) Reset()
func (*BuildIdAssignmentRule) String ¶
func (x *BuildIdAssignmentRule) String() string
type BuildIdAssignmentRule_PercentageRamp ¶
type BuildIdAssignmentRule_PercentageRamp struct {
// This ramp is useful for gradual Blue/Green deployments (and similar)
// where you want to send a certain portion of the traffic to the target
// Build ID.
PercentageRamp *RampByPercentage `protobuf:"bytes,3,opt,name=percentage_ramp,json=percentageRamp,proto3,oneof"`
}
type BuildIdReachability ¶
type BuildIdReachability struct {
// A build id or empty if unversioned.
BuildId string `protobuf:"bytes,1,opt,name=build_id,json=buildId,proto3" json:"build_id,omitempty"`
// Reachability per task queue.
TaskQueueReachability []*TaskQueueReachability `` /* 126-byte string literal not displayed */
// contains filtered or unexported fields
}
Reachability of tasks for a worker by build id, in one or more task queues.
func (*BuildIdReachability) Descriptor
deprecated
func (*BuildIdReachability) Descriptor() ([]byte, []int)
Deprecated: Use BuildIdReachability.ProtoReflect.Descriptor instead.
func (*BuildIdReachability) GetBuildId ¶
func (x *BuildIdReachability) GetBuildId() string
func (*BuildIdReachability) GetTaskQueueReachability ¶
func (x *BuildIdReachability) GetTaskQueueReachability() []*TaskQueueReachability
func (*BuildIdReachability) ProtoMessage ¶
func (*BuildIdReachability) ProtoMessage()
func (*BuildIdReachability) ProtoReflect ¶
func (x *BuildIdReachability) ProtoReflect() protoreflect.Message
func (*BuildIdReachability) Reset ¶
func (x *BuildIdReachability) Reset()
func (*BuildIdReachability) String ¶
func (x *BuildIdReachability) String() string
type CompatibleBuildIdRedirectRule ¶
type CompatibleBuildIdRedirectRule struct {
SourceBuildId string `protobuf:"bytes,1,opt,name=source_build_id,json=sourceBuildId,proto3" json:"source_build_id,omitempty"`
// Target Build ID must be compatible with the Source Build ID; that is it
// must be able to process event histories made by the Source Build ID by
// using [Patching](https://docs.temporal.io/workflows#patching) or other
// means.
TargetBuildId string `protobuf:"bytes,2,opt,name=target_build_id,json=targetBuildId,proto3" json:"target_build_id,omitempty"`
// contains filtered or unexported fields
}
These rules apply to tasks assigned to a particular Build ID (`source_build_id`) to redirect them to another *compatible* Build ID (`target_build_id`).
It is user's responsibility to ensure that the target Build ID is compatible with the source Build ID (e.g. by using the Patching API).
Most deployments are not expected to need these rules, however following situations can greatly benefit from redirects:
- Need to move long-running Workflow Executions from an old Build ID to a newer one.
- Need to hotfix some broken or stuck Workflow Executions.
In steady state, redirect rules are beneficial when dealing with old Executions ran on now-decommissioned Build IDs:
- To redirecting the Workflow Queries to the current (compatible) Build ID.
- To be able to Reset an old Execution so it can run on the current (compatible) Build ID.
Redirect rules can be chained.
func (*CompatibleBuildIdRedirectRule) Descriptor
deprecated
func (*CompatibleBuildIdRedirectRule) Descriptor() ([]byte, []int)
Deprecated: Use CompatibleBuildIdRedirectRule.ProtoReflect.Descriptor instead.
func (*CompatibleBuildIdRedirectRule) GetSourceBuildId ¶
func (x *CompatibleBuildIdRedirectRule) GetSourceBuildId() string
func (*CompatibleBuildIdRedirectRule) GetTargetBuildId ¶
func (x *CompatibleBuildIdRedirectRule) GetTargetBuildId() string
func (*CompatibleBuildIdRedirectRule) ProtoMessage ¶
func (*CompatibleBuildIdRedirectRule) ProtoMessage()
func (*CompatibleBuildIdRedirectRule) ProtoReflect ¶
func (x *CompatibleBuildIdRedirectRule) ProtoReflect() protoreflect.Message
func (*CompatibleBuildIdRedirectRule) Reset ¶
func (x *CompatibleBuildIdRedirectRule) Reset()
func (*CompatibleBuildIdRedirectRule) String ¶
func (x *CompatibleBuildIdRedirectRule) String() string
type CompatibleVersionSet ¶
type CompatibleVersionSet struct {
// All the compatible versions, unordered, except for the last element, which is considered the set "default".
BuildIds []string `protobuf:"bytes,1,rep,name=build_ids,json=buildIds,proto3" json:"build_ids,omitempty"`
// contains filtered or unexported fields
}
Used by the worker versioning APIs, represents an unordered set of one or more versions which are considered to be compatible with each other. Currently the versions are always worker build IDs.
func (*CompatibleVersionSet) Descriptor
deprecated
func (*CompatibleVersionSet) Descriptor() ([]byte, []int)
Deprecated: Use CompatibleVersionSet.ProtoReflect.Descriptor instead.
func (*CompatibleVersionSet) GetBuildIds ¶
func (x *CompatibleVersionSet) GetBuildIds() []string
func (*CompatibleVersionSet) ProtoMessage ¶
func (*CompatibleVersionSet) ProtoMessage()
func (*CompatibleVersionSet) ProtoReflect ¶
func (x *CompatibleVersionSet) ProtoReflect() protoreflect.Message
func (*CompatibleVersionSet) Reset ¶
func (x *CompatibleVersionSet) Reset()
func (*CompatibleVersionSet) String ¶
func (x *CompatibleVersionSet) String() string
type ConfigMetadata ¶
type ConfigMetadata struct {
// Reason for why the config was set.
Reason string `protobuf:"bytes,1,opt,name=reason,proto3" json:"reason,omitempty"`
// Identity of the last updater.
// Set by the request's identity field.
UpdateIdentity string `protobuf:"bytes,2,opt,name=update_identity,json=updateIdentity,proto3" json:"update_identity,omitempty"`
// Time of the last update.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// contains filtered or unexported fields
}
func (*ConfigMetadata) Descriptor
deprecated
func (*ConfigMetadata) Descriptor() ([]byte, []int)
Deprecated: Use ConfigMetadata.ProtoReflect.Descriptor instead.
func (*ConfigMetadata) GetReason ¶
func (x *ConfigMetadata) GetReason() string
func (*ConfigMetadata) GetUpdateIdentity ¶
func (x *ConfigMetadata) GetUpdateIdentity() string
func (*ConfigMetadata) GetUpdateTime ¶
func (x *ConfigMetadata) GetUpdateTime() *timestamppb.Timestamp
func (*ConfigMetadata) ProtoMessage ¶
func (*ConfigMetadata) ProtoMessage()
func (*ConfigMetadata) ProtoReflect ¶
func (x *ConfigMetadata) ProtoReflect() protoreflect.Message
func (*ConfigMetadata) Reset ¶
func (x *ConfigMetadata) Reset()
func (*ConfigMetadata) String ¶
func (x *ConfigMetadata) String() string
type PollerGroupInfo ¶
type PollerGroupInfo struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Weight float32 `protobuf:"fixed32,2,opt,name=weight,proto3" json:"weight,omitempty"`
// contains filtered or unexported fields
}
func (*PollerGroupInfo) Descriptor
deprecated
func (*PollerGroupInfo) Descriptor() ([]byte, []int)
Deprecated: Use PollerGroupInfo.ProtoReflect.Descriptor instead.
func (*PollerGroupInfo) GetId ¶
func (x *PollerGroupInfo) GetId() string
func (*PollerGroupInfo) GetWeight ¶
func (x *PollerGroupInfo) GetWeight() float32
func (*PollerGroupInfo) ProtoMessage ¶
func (*PollerGroupInfo) ProtoMessage()
func (*PollerGroupInfo) ProtoReflect ¶
func (x *PollerGroupInfo) ProtoReflect() protoreflect.Message
func (*PollerGroupInfo) Reset ¶
func (x *PollerGroupInfo) Reset()
func (*PollerGroupInfo) String ¶
func (x *PollerGroupInfo) String() string
type PollerInfo ¶
type PollerInfo struct {
LastAccessTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=last_access_time,json=lastAccessTime,proto3" json:"last_access_time,omitempty"`
Identity string `protobuf:"bytes,2,opt,name=identity,proto3" json:"identity,omitempty"`
RatePerSecond float64 `protobuf:"fixed64,3,opt,name=rate_per_second,json=ratePerSecond,proto3" json:"rate_per_second,omitempty"`
// If a worker has opted into the worker versioning feature while polling, its capabilities will
// appear here.
// Deprecated. Replaced by deployment_options.
//
// Deprecated: Marked as deprecated in temporal/api_next/taskqueue/v1/message.proto.
WorkerVersionCapabilities *v12.WorkerVersionCapabilities `` /* 138-byte string literal not displayed */
// Worker deployment options that SDK sent to server.
DeploymentOptions *v11.WorkerDeploymentOptions `protobuf:"bytes,5,opt,name=deployment_options,json=deploymentOptions,proto3" json:"deployment_options,omitempty"`
// contains filtered or unexported fields
}
func (*PollerInfo) Descriptor
deprecated
func (*PollerInfo) Descriptor() ([]byte, []int)
Deprecated: Use PollerInfo.ProtoReflect.Descriptor instead.
func (*PollerInfo) GetDeploymentOptions ¶
func (x *PollerInfo) GetDeploymentOptions() *v11.WorkerDeploymentOptions
func (*PollerInfo) GetIdentity ¶
func (x *PollerInfo) GetIdentity() string
func (*PollerInfo) GetLastAccessTime ¶
func (x *PollerInfo) GetLastAccessTime() *timestamppb.Timestamp
func (*PollerInfo) GetRatePerSecond ¶
func (x *PollerInfo) GetRatePerSecond() float64
func (*PollerInfo) GetWorkerVersionCapabilities
deprecated
func (x *PollerInfo) GetWorkerVersionCapabilities() *v12.WorkerVersionCapabilities
Deprecated: Marked as deprecated in temporal/api_next/taskqueue/v1/message.proto.
func (*PollerInfo) ProtoMessage ¶
func (*PollerInfo) ProtoMessage()
func (*PollerInfo) ProtoReflect ¶
func (x *PollerInfo) ProtoReflect() protoreflect.Message
func (*PollerInfo) Reset ¶
func (x *PollerInfo) Reset()
func (*PollerInfo) String ¶
func (x *PollerInfo) String() string
type PollerScalingDecision ¶
type PollerScalingDecision struct {
// How many poll requests to suggest should be added or removed, if any. As of now, server only
// scales up or down by 1. However, SDKs should allow for other values (while staying within
// defined min/max).
//
// The SDK is free to ignore this suggestion, EX: making more polls would not make sense because
// all slots are already occupied.
PollRequestDeltaSuggestion int32 `` /* 144-byte string literal not displayed */
// contains filtered or unexported fields
}
Attached to task responses to give hints to the SDK about how it may adjust its number of pollers.
func (*PollerScalingDecision) Descriptor
deprecated
func (*PollerScalingDecision) Descriptor() ([]byte, []int)
Deprecated: Use PollerScalingDecision.ProtoReflect.Descriptor instead.
func (*PollerScalingDecision) GetPollRequestDeltaSuggestion ¶
func (x *PollerScalingDecision) GetPollRequestDeltaSuggestion() int32
func (*PollerScalingDecision) ProtoMessage ¶
func (*PollerScalingDecision) ProtoMessage()
func (*PollerScalingDecision) ProtoReflect ¶
func (x *PollerScalingDecision) ProtoReflect() protoreflect.Message
func (*PollerScalingDecision) Reset ¶
func (x *PollerScalingDecision) Reset()
func (*PollerScalingDecision) String ¶
func (x *PollerScalingDecision) String() string
type RampByPercentage ¶
type RampByPercentage struct {
// Acceptable range is [0,100).
RampPercentage float32 `protobuf:"fixed32,1,opt,name=ramp_percentage,json=rampPercentage,proto3" json:"ramp_percentage,omitempty"`
// contains filtered or unexported fields
}
func (*RampByPercentage) Descriptor
deprecated
func (*RampByPercentage) Descriptor() ([]byte, []int)
Deprecated: Use RampByPercentage.ProtoReflect.Descriptor instead.
func (*RampByPercentage) GetRampPercentage ¶
func (x *RampByPercentage) GetRampPercentage() float32
func (*RampByPercentage) ProtoMessage ¶
func (*RampByPercentage) ProtoMessage()
func (*RampByPercentage) ProtoReflect ¶
func (x *RampByPercentage) ProtoReflect() protoreflect.Message
func (*RampByPercentage) Reset ¶
func (x *RampByPercentage) Reset()
func (*RampByPercentage) String ¶
func (x *RampByPercentage) String() string
type RateLimit ¶
type RateLimit struct {
// Zero is a valid rate limit.
RequestsPerSecond float32 `protobuf:"fixed32,1,opt,name=requests_per_second,json=requestsPerSecond,proto3" json:"requests_per_second,omitempty"`
// contains filtered or unexported fields
}
func (*RateLimit) Descriptor
deprecated
func (*RateLimit) GetRequestsPerSecond ¶
func (*RateLimit) ProtoMessage ¶
func (*RateLimit) ProtoMessage()
func (*RateLimit) ProtoReflect ¶
func (x *RateLimit) ProtoReflect() protoreflect.Message
type RateLimitConfig ¶
type RateLimitConfig struct {
RateLimit *RateLimit `protobuf:"bytes,1,opt,name=rate_limit,json=rateLimit,proto3" json:"rate_limit,omitempty"`
Metadata *ConfigMetadata `protobuf:"bytes,2,opt,name=metadata,proto3" json:"metadata,omitempty"`
// contains filtered or unexported fields
}
func (*RateLimitConfig) Descriptor
deprecated
func (*RateLimitConfig) Descriptor() ([]byte, []int)
Deprecated: Use RateLimitConfig.ProtoReflect.Descriptor instead.
func (*RateLimitConfig) GetMetadata ¶
func (x *RateLimitConfig) GetMetadata() *ConfigMetadata
func (*RateLimitConfig) GetRateLimit ¶
func (x *RateLimitConfig) GetRateLimit() *RateLimit
func (*RateLimitConfig) ProtoMessage ¶
func (*RateLimitConfig) ProtoMessage()
func (*RateLimitConfig) ProtoReflect ¶
func (x *RateLimitConfig) ProtoReflect() protoreflect.Message
func (*RateLimitConfig) Reset ¶
func (x *RateLimitConfig) Reset()
func (*RateLimitConfig) String ¶
func (x *RateLimitConfig) String() string
type StickyExecutionAttributes ¶
type StickyExecutionAttributes struct {
WorkerTaskQueue *TaskQueue `protobuf:"bytes,1,opt,name=worker_task_queue,json=workerTaskQueue,proto3" json:"worker_task_queue,omitempty"`
// (-- api-linter: core::0140::prepositions=disabled
//
// aip.dev/not-precedent: "to" is used to indicate interval. --)
ScheduleToStartTimeout *durationpb.Duration `` /* 131-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*StickyExecutionAttributes) Descriptor
deprecated
func (*StickyExecutionAttributes) Descriptor() ([]byte, []int)
Deprecated: Use StickyExecutionAttributes.ProtoReflect.Descriptor instead.
func (*StickyExecutionAttributes) GetScheduleToStartTimeout ¶
func (x *StickyExecutionAttributes) GetScheduleToStartTimeout() *durationpb.Duration
func (*StickyExecutionAttributes) GetWorkerTaskQueue ¶
func (x *StickyExecutionAttributes) GetWorkerTaskQueue() *TaskQueue
func (*StickyExecutionAttributes) ProtoMessage ¶
func (*StickyExecutionAttributes) ProtoMessage()
func (*StickyExecutionAttributes) ProtoReflect ¶
func (x *StickyExecutionAttributes) ProtoReflect() protoreflect.Message
func (*StickyExecutionAttributes) Reset ¶
func (x *StickyExecutionAttributes) Reset()
func (*StickyExecutionAttributes) String ¶
func (x *StickyExecutionAttributes) String() string
type TaskIdBlock ¶
type TaskIdBlock struct {
StartId int64 `protobuf:"varint,1,opt,name=start_id,json=startId,proto3" json:"start_id,omitempty"`
EndId int64 `protobuf:"varint,2,opt,name=end_id,json=endId,proto3" json:"end_id,omitempty"`
// contains filtered or unexported fields
}
func (*TaskIdBlock) Descriptor
deprecated
func (*TaskIdBlock) Descriptor() ([]byte, []int)
Deprecated: Use TaskIdBlock.ProtoReflect.Descriptor instead.
func (*TaskIdBlock) GetEndId ¶
func (x *TaskIdBlock) GetEndId() int64
func (*TaskIdBlock) GetStartId ¶
func (x *TaskIdBlock) GetStartId() int64
func (*TaskIdBlock) ProtoMessage ¶
func (*TaskIdBlock) ProtoMessage()
func (*TaskIdBlock) ProtoReflect ¶
func (x *TaskIdBlock) ProtoReflect() protoreflect.Message
func (*TaskIdBlock) Reset ¶
func (x *TaskIdBlock) Reset()
func (*TaskIdBlock) String ¶
func (x *TaskIdBlock) String() string
type TaskQueue ¶
type TaskQueue struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Default: TASK_QUEUE_KIND_NORMAL.
Kind v1.TaskQueueKind `protobuf:"varint,2,opt,name=kind,proto3,enum=temporal.api.enums.v1.TaskQueueKind" json:"kind,omitempty"`
// Iff kind == TASK_QUEUE_KIND_STICKY, then this field contains the name of
// the normal task queue that the sticky worker is running on.
NormalName string `protobuf:"bytes,3,opt,name=normal_name,json=normalName,proto3" json:"normal_name,omitempty"`
// contains filtered or unexported fields
}
See https://docs.temporal.io/docs/concepts/task-queues/
func (*TaskQueue) Descriptor
deprecated
func (*TaskQueue) GetKind ¶
func (x *TaskQueue) GetKind() v1.TaskQueueKind
func (*TaskQueue) GetNormalName ¶
func (*TaskQueue) ProtoMessage ¶
func (*TaskQueue) ProtoMessage()
func (*TaskQueue) ProtoReflect ¶
func (x *TaskQueue) ProtoReflect() protoreflect.Message
type TaskQueueConfig ¶
type TaskQueueConfig struct {
// Unless modified, this is the system-defined rate limit.
QueueRateLimit *RateLimitConfig `protobuf:"bytes,1,opt,name=queue_rate_limit,json=queueRateLimit,proto3" json:"queue_rate_limit,omitempty"`
// If set, each individual fairness key will be limited to this rate, scaled by the weight of the fairness key.
FairnessKeysRateLimitDefault *RateLimitConfig `` /* 151-byte string literal not displayed */
// If set, overrides the fairness weights for the corresponding fairness keys.
FairnessWeightOverrides map[string]float32 `` /* 208-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*TaskQueueConfig) Descriptor
deprecated
func (*TaskQueueConfig) Descriptor() ([]byte, []int)
Deprecated: Use TaskQueueConfig.ProtoReflect.Descriptor instead.
func (*TaskQueueConfig) GetFairnessKeysRateLimitDefault ¶
func (x *TaskQueueConfig) GetFairnessKeysRateLimitDefault() *RateLimitConfig
func (*TaskQueueConfig) GetFairnessWeightOverrides ¶
func (x *TaskQueueConfig) GetFairnessWeightOverrides() map[string]float32
func (*TaskQueueConfig) GetQueueRateLimit ¶
func (x *TaskQueueConfig) GetQueueRateLimit() *RateLimitConfig
func (*TaskQueueConfig) ProtoMessage ¶
func (*TaskQueueConfig) ProtoMessage()
func (*TaskQueueConfig) ProtoReflect ¶
func (x *TaskQueueConfig) ProtoReflect() protoreflect.Message
func (*TaskQueueConfig) Reset ¶
func (x *TaskQueueConfig) Reset()
func (*TaskQueueConfig) String ¶
func (x *TaskQueueConfig) String() string
type TaskQueueMetadata ¶
type TaskQueueMetadata struct {
// Allows throttling dispatch of tasks from this queue
MaxTasksPerSecond *wrapperspb.DoubleValue `protobuf:"bytes,1,opt,name=max_tasks_per_second,json=maxTasksPerSecond,proto3" json:"max_tasks_per_second,omitempty"`
// contains filtered or unexported fields
}
Only applies to activity task queues
func (*TaskQueueMetadata) Descriptor
deprecated
func (*TaskQueueMetadata) Descriptor() ([]byte, []int)
Deprecated: Use TaskQueueMetadata.ProtoReflect.Descriptor instead.
func (*TaskQueueMetadata) GetMaxTasksPerSecond ¶
func (x *TaskQueueMetadata) GetMaxTasksPerSecond() *wrapperspb.DoubleValue
func (*TaskQueueMetadata) ProtoMessage ¶
func (*TaskQueueMetadata) ProtoMessage()
func (*TaskQueueMetadata) ProtoReflect ¶
func (x *TaskQueueMetadata) ProtoReflect() protoreflect.Message
func (*TaskQueueMetadata) Reset ¶
func (x *TaskQueueMetadata) Reset()
func (*TaskQueueMetadata) String ¶
func (x *TaskQueueMetadata) String() string
type TaskQueuePartitionMetadata ¶
type TaskQueuePartitionMetadata struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
OwnerHostName string `protobuf:"bytes,2,opt,name=owner_host_name,json=ownerHostName,proto3" json:"owner_host_name,omitempty"`
// contains filtered or unexported fields
}
func (*TaskQueuePartitionMetadata) Descriptor
deprecated
func (*TaskQueuePartitionMetadata) Descriptor() ([]byte, []int)
Deprecated: Use TaskQueuePartitionMetadata.ProtoReflect.Descriptor instead.
func (*TaskQueuePartitionMetadata) GetKey ¶
func (x *TaskQueuePartitionMetadata) GetKey() string
func (*TaskQueuePartitionMetadata) GetOwnerHostName ¶
func (x *TaskQueuePartitionMetadata) GetOwnerHostName() string
func (*TaskQueuePartitionMetadata) ProtoMessage ¶
func (*TaskQueuePartitionMetadata) ProtoMessage()
func (*TaskQueuePartitionMetadata) ProtoReflect ¶
func (x *TaskQueuePartitionMetadata) ProtoReflect() protoreflect.Message
func (*TaskQueuePartitionMetadata) Reset ¶
func (x *TaskQueuePartitionMetadata) Reset()
func (*TaskQueuePartitionMetadata) String ¶
func (x *TaskQueuePartitionMetadata) String() string
type TaskQueueReachability ¶
type TaskQueueReachability struct {
TaskQueue string `protobuf:"bytes,1,opt,name=task_queue,json=taskQueue,proto3" json:"task_queue,omitempty"`
// Task reachability for a worker in a single task queue.
// See the TaskReachability docstring for information about each enum variant.
// If reachability is empty, this worker is considered unreachable in this task queue.
Reachability []v1.TaskReachability `` /* 129-byte string literal not displayed */
// contains filtered or unexported fields
}
Reachability of tasks for a worker on a single task queue.
func (*TaskQueueReachability) Descriptor
deprecated
func (*TaskQueueReachability) Descriptor() ([]byte, []int)
Deprecated: Use TaskQueueReachability.ProtoReflect.Descriptor instead.
func (*TaskQueueReachability) GetReachability ¶
func (x *TaskQueueReachability) GetReachability() []v1.TaskReachability
func (*TaskQueueReachability) GetTaskQueue ¶
func (x *TaskQueueReachability) GetTaskQueue() string
func (*TaskQueueReachability) ProtoMessage ¶
func (*TaskQueueReachability) ProtoMessage()
func (*TaskQueueReachability) ProtoReflect ¶
func (x *TaskQueueReachability) ProtoReflect() protoreflect.Message
func (*TaskQueueReachability) Reset ¶
func (x *TaskQueueReachability) Reset()
func (*TaskQueueReachability) String ¶
func (x *TaskQueueReachability) String() string
type TaskQueueStats ¶
type TaskQueueStats struct {
// The approximate number of tasks backlogged in this task queue. May count expired tasks but eventually
// converges to the right value. Can be relied upon for scaling decisions.
//
// Special note for workflow task queue type: this metric does not count sticky queue tasks. However, because
// those tasks only remain valid for a few seconds, the inaccuracy becomes less significant as the backlog size
// grows.
ApproximateBacklogCount int64 `` /* 133-byte string literal not displayed */
// Approximate age of the oldest task in the backlog based on the creation time of the task at the head of
// the queue. Can be relied upon for scaling decisions.
//
// Special note for workflow task queue type: this metric does not count sticky queue tasks. However, because
// those tasks only remain valid for a few seconds, they should not affect the result when backlog is older than
// few seconds.
ApproximateBacklogAge *durationpb.Duration `` /* 126-byte string literal not displayed */
// The approximate tasks per second added to the task queue, averaging the last 30 seconds. These includes tasks
// whether or not they were added to/dispatched from the backlog or they were dispatched immediately without going
// to the backlog (sync-matched).
//
// The difference between `tasks_add_rate` and `tasks_dispatch_rate` is a reliable metric for the rate at which
// backlog grows/shrinks.
//
// Note: the actual tasks delivered to the workers may significantly be higher than the numbers reported by
// tasks_add_rate, because:
// - Tasks can be sent to workers without going to the task queue. This is called Eager dispatch. Eager dispatch is
// enable for activities by default in the latest SDKs.
// - Tasks going to Sticky queue are not accounted for. Note that, typically, only the first workflow task of each
// workflow goes to a normal queue, and the rest workflow tasks go to the Sticky queue associated with a specific
// worker instance.
TasksAddRate float32 `protobuf:"fixed32,3,opt,name=tasks_add_rate,json=tasksAddRate,proto3" json:"tasks_add_rate,omitempty"`
// The approximate tasks per second dispatched from the task queue, averaging the last 30 seconds. These includes
// tasks whether or not they were added to/dispatched from the backlog or they were dispatched immediately without
// going to the backlog (sync-matched).
//
// The difference between `tasks_add_rate` and `tasks_dispatch_rate` is a reliable metric for the rate at which
// backlog grows/shrinks.
//
// Note: the actual tasks delivered to the workers may significantly be higher than the numbers reported by
// tasks_dispatch_rate, because:
// - Tasks can be sent to workers without going to the task queue. This is called Eager dispatch. Eager dispatch is
// enable for activities by default in the latest SDKs.
// - Tasks going to Sticky queue are not accounted for. Note that, typically, only the first workflow task of each
// workflow goes to a normal queue, and the rest workflow tasks go to the Sticky queue associated with a specific
// worker instance.
TasksDispatchRate float32 `protobuf:"fixed32,4,opt,name=tasks_dispatch_rate,json=tasksDispatchRate,proto3" json:"tasks_dispatch_rate,omitempty"`
// contains filtered or unexported fields
}
TaskQueueStats contains statistics about task queue backlog and activity.
For workflow task queue type, this result is partial because tasks sent to sticky queues are not included. Read comments above each metric to understand the impact of sticky queue exclusion on that metric accuracy.
func (*TaskQueueStats) Descriptor
deprecated
func (*TaskQueueStats) Descriptor() ([]byte, []int)
Deprecated: Use TaskQueueStats.ProtoReflect.Descriptor instead.
func (*TaskQueueStats) GetApproximateBacklogAge ¶
func (x *TaskQueueStats) GetApproximateBacklogAge() *durationpb.Duration
func (*TaskQueueStats) GetApproximateBacklogCount ¶
func (x *TaskQueueStats) GetApproximateBacklogCount() int64
func (*TaskQueueStats) GetTasksAddRate ¶
func (x *TaskQueueStats) GetTasksAddRate() float32
func (*TaskQueueStats) GetTasksDispatchRate ¶
func (x *TaskQueueStats) GetTasksDispatchRate() float32
func (*TaskQueueStats) ProtoMessage ¶
func (*TaskQueueStats) ProtoMessage()
func (*TaskQueueStats) ProtoReflect ¶
func (x *TaskQueueStats) ProtoReflect() protoreflect.Message
func (*TaskQueueStats) Reset ¶
func (x *TaskQueueStats) Reset()
func (*TaskQueueStats) String ¶
func (x *TaskQueueStats) String() string
type TaskQueueStatus ¶
type TaskQueueStatus struct {
BacklogCountHint int64 `protobuf:"varint,1,opt,name=backlog_count_hint,json=backlogCountHint,proto3" json:"backlog_count_hint,omitempty"`
ReadLevel int64 `protobuf:"varint,2,opt,name=read_level,json=readLevel,proto3" json:"read_level,omitempty"`
AckLevel int64 `protobuf:"varint,3,opt,name=ack_level,json=ackLevel,proto3" json:"ack_level,omitempty"`
RatePerSecond float64 `protobuf:"fixed64,4,opt,name=rate_per_second,json=ratePerSecond,proto3" json:"rate_per_second,omitempty"`
TaskIdBlock *TaskIdBlock `protobuf:"bytes,5,opt,name=task_id_block,json=taskIdBlock,proto3" json:"task_id_block,omitempty"`
// contains filtered or unexported fields
}
Deprecated. Use `InternalTaskQueueStatus`. This is kept until `DescribeTaskQueue` supports legacy behavior.
func (*TaskQueueStatus) Descriptor
deprecated
func (*TaskQueueStatus) Descriptor() ([]byte, []int)
Deprecated: Use TaskQueueStatus.ProtoReflect.Descriptor instead.
func (*TaskQueueStatus) GetAckLevel ¶
func (x *TaskQueueStatus) GetAckLevel() int64
func (*TaskQueueStatus) GetBacklogCountHint ¶
func (x *TaskQueueStatus) GetBacklogCountHint() int64
func (*TaskQueueStatus) GetRatePerSecond ¶
func (x *TaskQueueStatus) GetRatePerSecond() float64
func (*TaskQueueStatus) GetReadLevel ¶
func (x *TaskQueueStatus) GetReadLevel() int64
func (*TaskQueueStatus) GetTaskIdBlock ¶
func (x *TaskQueueStatus) GetTaskIdBlock() *TaskIdBlock
func (*TaskQueueStatus) ProtoMessage ¶
func (*TaskQueueStatus) ProtoMessage()
func (*TaskQueueStatus) ProtoReflect ¶
func (x *TaskQueueStatus) ProtoReflect() protoreflect.Message
func (*TaskQueueStatus) Reset ¶
func (x *TaskQueueStatus) Reset()
func (*TaskQueueStatus) String ¶
func (x *TaskQueueStatus) String() string
type TaskQueueTypeInfo ¶
type TaskQueueTypeInfo struct {
// Unversioned workers (with `useVersioning=false`) are reported in unversioned result even if they set a Build ID.
Pollers []*PollerInfo `protobuf:"bytes,1,rep,name=pollers,proto3" json:"pollers,omitempty"`
Stats *TaskQueueStats `protobuf:"bytes,2,opt,name=stats,proto3" json:"stats,omitempty"`
// contains filtered or unexported fields
}
func (*TaskQueueTypeInfo) Descriptor
deprecated
func (*TaskQueueTypeInfo) Descriptor() ([]byte, []int)
Deprecated: Use TaskQueueTypeInfo.ProtoReflect.Descriptor instead.
func (*TaskQueueTypeInfo) GetPollers ¶
func (x *TaskQueueTypeInfo) GetPollers() []*PollerInfo
func (*TaskQueueTypeInfo) GetStats ¶
func (x *TaskQueueTypeInfo) GetStats() *TaskQueueStats
func (*TaskQueueTypeInfo) ProtoMessage ¶
func (*TaskQueueTypeInfo) ProtoMessage()
func (*TaskQueueTypeInfo) ProtoReflect ¶
func (x *TaskQueueTypeInfo) ProtoReflect() protoreflect.Message
func (*TaskQueueTypeInfo) Reset ¶
func (x *TaskQueueTypeInfo) Reset()
func (*TaskQueueTypeInfo) String ¶
func (x *TaskQueueTypeInfo) String() string
type TaskQueueVersionInfo ¶
type TaskQueueVersionInfo struct {
// Task Queue info per Task Type. Key is the numerical value of the temporal.api.enums.v1.TaskQueueType enum.
TypesInfo map[int32]*TaskQueueTypeInfo `` /* 163-byte string literal not displayed */
// Task Reachability is eventually consistent; there may be a delay until it converges to the most
// accurate value but it is designed in a way to take the more conservative side until it converges.
// For example REACHABLE is more conservative than CLOSED_WORKFLOWS_ONLY.
//
// Note: future activities who inherit their workflow's Build ID but not its Task Queue will not be
// accounted for reachability as server cannot know if they'll happen as they do not use
// assignment rules of their Task Queue. Same goes for Child Workflows or Continue-As-New Workflows
// who inherit the parent/previous workflow's Build ID but not its Task Queue. In those cases, make
// sure to query reachability for the parent/previous workflow's Task Queue as well.
TaskReachability v1.BuildIdTaskReachability `` /* 161-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*TaskQueueVersionInfo) Descriptor
deprecated
func (*TaskQueueVersionInfo) Descriptor() ([]byte, []int)
Deprecated: Use TaskQueueVersionInfo.ProtoReflect.Descriptor instead.
func (*TaskQueueVersionInfo) GetTaskReachability ¶
func (x *TaskQueueVersionInfo) GetTaskReachability() v1.BuildIdTaskReachability
func (*TaskQueueVersionInfo) GetTypesInfo ¶
func (x *TaskQueueVersionInfo) GetTypesInfo() map[int32]*TaskQueueTypeInfo
func (*TaskQueueVersionInfo) ProtoMessage ¶
func (*TaskQueueVersionInfo) ProtoMessage()
func (*TaskQueueVersionInfo) ProtoReflect ¶
func (x *TaskQueueVersionInfo) ProtoReflect() protoreflect.Message
func (*TaskQueueVersionInfo) Reset ¶
func (x *TaskQueueVersionInfo) Reset()
func (*TaskQueueVersionInfo) String ¶
func (x *TaskQueueVersionInfo) String() string
type TaskQueueVersionSelection ¶
type TaskQueueVersionSelection struct {
// Include specific Build IDs.
BuildIds []string `protobuf:"bytes,1,rep,name=build_ids,json=buildIds,proto3" json:"build_ids,omitempty"`
// Include the unversioned queue.
Unversioned bool `protobuf:"varint,2,opt,name=unversioned,proto3" json:"unversioned,omitempty"`
// Include all active versions. A version is considered active if, in the last few minutes,
// it has had new tasks or polls, or it has been the subject of certain task queue API calls.
AllActive bool `protobuf:"varint,3,opt,name=all_active,json=allActive,proto3" json:"all_active,omitempty"`
// contains filtered or unexported fields
}
Used for specifying versions the caller is interested in.
func (*TaskQueueVersionSelection) Descriptor
deprecated
func (*TaskQueueVersionSelection) Descriptor() ([]byte, []int)
Deprecated: Use TaskQueueVersionSelection.ProtoReflect.Descriptor instead.
func (*TaskQueueVersionSelection) GetAllActive ¶
func (x *TaskQueueVersionSelection) GetAllActive() bool
func (*TaskQueueVersionSelection) GetBuildIds ¶
func (x *TaskQueueVersionSelection) GetBuildIds() []string
func (*TaskQueueVersionSelection) GetUnversioned ¶
func (x *TaskQueueVersionSelection) GetUnversioned() bool
func (*TaskQueueVersionSelection) ProtoMessage ¶
func (*TaskQueueVersionSelection) ProtoMessage()
func (*TaskQueueVersionSelection) ProtoReflect ¶
func (x *TaskQueueVersionSelection) ProtoReflect() protoreflect.Message
func (*TaskQueueVersionSelection) Reset ¶
func (x *TaskQueueVersionSelection) Reset()
func (*TaskQueueVersionSelection) String ¶
func (x *TaskQueueVersionSelection) String() string
type TaskQueueVersioningInfo ¶
type TaskQueueVersioningInfo struct {
// Specifies which Deployment Version should receive new workflow executions and tasks of
// existing unversioned or AutoUpgrade workflows.
// Nil value represents all the unversioned workers (those with `UNVERSIONED` (or unspecified) `WorkerVersioningMode`.)
// Note: Current Version is overridden by the Ramping Version for a portion of traffic when ramp percentage
// is non-zero (see `ramping_deployment_version` and `ramping_version_percentage`).
CurrentDeploymentVersion *v11.WorkerDeploymentVersion `` /* 135-byte string literal not displayed */
// Deprecated. Use `current_deployment_version`.
//
// Deprecated: Marked as deprecated in temporal/api_next/taskqueue/v1/message.proto.
CurrentVersion string `protobuf:"bytes,1,opt,name=current_version,json=currentVersion,proto3" json:"current_version,omitempty"`
// When ramp percentage is non-zero, that portion of traffic is shifted from the Current Version to the Ramping Version.
// Must always be different from `current_deployment_version` unless both are nil.
// Nil value represents all the unversioned workers (those with `UNVERSIONED` (or unspecified) `WorkerVersioningMode`.)
// Note that it is possible to ramp from one Version to another Version, or from unversioned
// workers to a particular Version, or from a particular Version to unversioned workers.
RampingDeploymentVersion *v11.WorkerDeploymentVersion `` /* 135-byte string literal not displayed */
// Deprecated. Use `ramping_deployment_version`.
//
// Deprecated: Marked as deprecated in temporal/api_next/taskqueue/v1/message.proto.
RampingVersion string `protobuf:"bytes,2,opt,name=ramping_version,json=rampingVersion,proto3" json:"ramping_version,omitempty"`
// Percentage of tasks that are routed to the Ramping Version instead of the Current Version.
// Valid range: [0, 100]. A 100% value means the Ramping Version is receiving full traffic but
// not yet "promoted" to be the Current Version, likely due to pending validations.
// A 0% value means the Ramping Version is receiving no traffic.
RampingVersionPercentage float32 `` /* 137-byte string literal not displayed */
// Last time versioning information of this Task Queue changed.
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// contains filtered or unexported fields
}
func (*TaskQueueVersioningInfo) Descriptor
deprecated
func (*TaskQueueVersioningInfo) Descriptor() ([]byte, []int)
Deprecated: Use TaskQueueVersioningInfo.ProtoReflect.Descriptor instead.
func (*TaskQueueVersioningInfo) GetCurrentDeploymentVersion ¶
func (x *TaskQueueVersioningInfo) GetCurrentDeploymentVersion() *v11.WorkerDeploymentVersion
func (*TaskQueueVersioningInfo) GetCurrentVersion
deprecated
func (x *TaskQueueVersioningInfo) GetCurrentVersion() string
Deprecated: Marked as deprecated in temporal/api_next/taskqueue/v1/message.proto.
func (*TaskQueueVersioningInfo) GetRampingDeploymentVersion ¶
func (x *TaskQueueVersioningInfo) GetRampingDeploymentVersion() *v11.WorkerDeploymentVersion
func (*TaskQueueVersioningInfo) GetRampingVersion
deprecated
func (x *TaskQueueVersioningInfo) GetRampingVersion() string
Deprecated: Marked as deprecated in temporal/api_next/taskqueue/v1/message.proto.
func (*TaskQueueVersioningInfo) GetRampingVersionPercentage ¶
func (x *TaskQueueVersioningInfo) GetRampingVersionPercentage() float32
func (*TaskQueueVersioningInfo) GetUpdateTime ¶
func (x *TaskQueueVersioningInfo) GetUpdateTime() *timestamppb.Timestamp
func (*TaskQueueVersioningInfo) ProtoMessage ¶
func (*TaskQueueVersioningInfo) ProtoMessage()
func (*TaskQueueVersioningInfo) ProtoReflect ¶
func (x *TaskQueueVersioningInfo) ProtoReflect() protoreflect.Message
func (*TaskQueueVersioningInfo) Reset ¶
func (x *TaskQueueVersioningInfo) Reset()
func (*TaskQueueVersioningInfo) String ¶
func (x *TaskQueueVersioningInfo) String() string
type TimestampedBuildIdAssignmentRule ¶
type TimestampedBuildIdAssignmentRule struct {
Rule *BuildIdAssignmentRule `protobuf:"bytes,1,opt,name=rule,proto3" json:"rule,omitempty"`
CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// contains filtered or unexported fields
}
func (*TimestampedBuildIdAssignmentRule) Descriptor
deprecated
func (*TimestampedBuildIdAssignmentRule) Descriptor() ([]byte, []int)
Deprecated: Use TimestampedBuildIdAssignmentRule.ProtoReflect.Descriptor instead.
func (*TimestampedBuildIdAssignmentRule) GetCreateTime ¶
func (x *TimestampedBuildIdAssignmentRule) GetCreateTime() *timestamppb.Timestamp
func (*TimestampedBuildIdAssignmentRule) GetRule ¶
func (x *TimestampedBuildIdAssignmentRule) GetRule() *BuildIdAssignmentRule
func (*TimestampedBuildIdAssignmentRule) ProtoMessage ¶
func (*TimestampedBuildIdAssignmentRule) ProtoMessage()
func (*TimestampedBuildIdAssignmentRule) ProtoReflect ¶
func (x *TimestampedBuildIdAssignmentRule) ProtoReflect() protoreflect.Message
func (*TimestampedBuildIdAssignmentRule) Reset ¶
func (x *TimestampedBuildIdAssignmentRule) Reset()
func (*TimestampedBuildIdAssignmentRule) String ¶
func (x *TimestampedBuildIdAssignmentRule) String() string
type TimestampedCompatibleBuildIdRedirectRule ¶
type TimestampedCompatibleBuildIdRedirectRule struct {
Rule *CompatibleBuildIdRedirectRule `protobuf:"bytes,1,opt,name=rule,proto3" json:"rule,omitempty"`
CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// contains filtered or unexported fields
}
func (*TimestampedCompatibleBuildIdRedirectRule) Descriptor
deprecated
func (*TimestampedCompatibleBuildIdRedirectRule) Descriptor() ([]byte, []int)
Deprecated: Use TimestampedCompatibleBuildIdRedirectRule.ProtoReflect.Descriptor instead.
func (*TimestampedCompatibleBuildIdRedirectRule) GetCreateTime ¶
func (x *TimestampedCompatibleBuildIdRedirectRule) GetCreateTime() *timestamppb.Timestamp
func (*TimestampedCompatibleBuildIdRedirectRule) GetRule ¶
func (x *TimestampedCompatibleBuildIdRedirectRule) GetRule() *CompatibleBuildIdRedirectRule
func (*TimestampedCompatibleBuildIdRedirectRule) ProtoMessage ¶
func (*TimestampedCompatibleBuildIdRedirectRule) ProtoMessage()
func (*TimestampedCompatibleBuildIdRedirectRule) ProtoReflect ¶
func (x *TimestampedCompatibleBuildIdRedirectRule) ProtoReflect() protoreflect.Message
func (*TimestampedCompatibleBuildIdRedirectRule) Reset ¶
func (x *TimestampedCompatibleBuildIdRedirectRule) Reset()
func (*TimestampedCompatibleBuildIdRedirectRule) String ¶
func (x *TimestampedCompatibleBuildIdRedirectRule) String() string